# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/metadataservice/metadata_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from tecton_proto.auth import principal_pb2 as tecton__proto_dot_auth_dot_principal__pb2
from tecton_proto.data import entity_pb2 as tecton__proto_dot_data_dot_entity__pb2
from tecton_proto.args import fco_args_pb2 as tecton__proto_dot_args_dot_fco__args__pb2
from tecton_proto.auth import service_pb2 as tecton__proto_dot_auth_dot_service__pb2
from tecton_proto.data import fco_pb2 as tecton__proto_dot_data_dot_fco__pb2
from tecton_proto.data import feature_view_pb2 as tecton__proto_dot_data_dot_feature__view__pb2
from tecton_proto.data import feature_service_pb2 as tecton__proto_dot_data_dot_feature__service__pb2
from tecton_proto.data import hive_metastore_pb2 as tecton__proto_dot_data_dot_hive__metastore__pb2
from tecton_proto.data import state_update_pb2 as tecton__proto_dot_data_dot_state__update__pb2
from tecton_proto.data import tecton_api_key_pb2 as tecton__proto_dot_data_dot_tecton__api__key__pb2
from tecton_proto.data import user_deployment_settings_pb2 as tecton__proto_dot_data_dot_user__deployment__settings__pb2
from tecton_proto.data import user_pb2 as tecton__proto_dot_data_dot_user__pb2
from tecton_proto.spark_common import clusters_pb2 as tecton__proto_dot_spark__common_dot_clusters__pb2
from tecton_proto.dataobs import expectation_pb2 as tecton__proto_dot_dataobs_dot_expectation__pb2
from tecton_proto.consumption import consumption_pb2 as tecton__proto_dot_consumption_dot_consumption__pb2
from tecton_proto.dataobs import metric_pb2 as tecton__proto_dot_dataobs_dot_metric__pb2
from tecton_proto.dataobs import validation_pb2 as tecton__proto_dot_dataobs_dot_validation__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.common import fco_locator_pb2 as tecton__proto_dot_common_dot_fco__locator__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2
from tecton_proto.data import materialization_status_pb2 as tecton__proto_dot_data_dot_materialization__status__pb2
from tecton_proto.data import freshness_status_pb2 as tecton__proto_dot_data_dot_freshness__status__pb2
from tecton_proto.data import serving_status_pb2 as tecton__proto_dot_data_dot_serving__status__pb2
from tecton_proto.data import internal_spark_cluster_status_pb2 as tecton__proto_dot_data_dot_internal__spark__cluster__status__pb2
from tecton_proto.data import summary_pb2 as tecton__proto_dot_data_dot_summary__pb2
from tecton_proto.data import saved_feature_data_frame_pb2 as tecton__proto_dot_data_dot_saved__feature__data__frame__pb2
from tecton_proto.data import onboarding_pb2 as tecton__proto_dot_data_dot_onboarding__pb2
from tecton_proto.data import transformation_pb2 as tecton__proto_dot_data_dot_transformation__pb2
from tecton_proto.data import virtual_data_source_pb2 as tecton__proto_dot_data_dot_virtual__data__source__pb2
from tecton_proto.data import workspace_pb2 as tecton__proto_dot_data_dot_workspace__pb2
from tecton_proto.amplitude import client_logging_pb2 as tecton__proto_dot_amplitude_dot_client__logging__pb2
from tecton_proto.amplitude import amplitude_pb2 as tecton__proto_dot_amplitude_dot_amplitude__pb2
from tecton_proto.validation import validator_pb2 as tecton__proto_dot_validation_dot_validator__pb2
from tecton_proto.materialization import materialization_states_pb2 as tecton__proto_dot_materialization_dot_materialization__states__pb2
from tecton_proto.materialization import spark_cluster_pb2 as tecton__proto_dot_materialization_dot_spark__cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3tecton_proto/metadataservice/metadata_service.proto\x12\x1ctecton_proto.metadataservice\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a google/protobuf/field_mask.proto\x1a!tecton_proto/auth/principal.proto\x1a\x1etecton_proto/data/entity.proto\x1a tecton_proto/args/fco_args.proto\x1a\x1ftecton_proto/auth/service.proto\x1a\x1btecton_proto/data/fco.proto\x1a$tecton_proto/data/feature_view.proto\x1a\'tecton_proto/data/feature_service.proto\x1a&tecton_proto/data/hive_metastore.proto\x1a$tecton_proto/data/state_update.proto\x1a&tecton_proto/data/tecton_api_key.proto\x1a\x30tecton_proto/data/user_deployment_settings.proto\x1a\x1ctecton_proto/data/user.proto\x1a(tecton_proto/spark_common/clusters.proto\x1a&tecton_proto/dataobs/expectation.proto\x1a*tecton_proto/consumption/consumption.proto\x1a!tecton_proto/dataobs/metric.proto\x1a%tecton_proto/dataobs/validation.proto\x1a\x1ctecton_proto/common/id.proto\x1a%tecton_proto/common/fco_locator.proto\x1a&tecton_proto/common/spark_schema.proto\x1a.tecton_proto/data/materialization_status.proto\x1a(tecton_proto/data/freshness_status.proto\x1a&tecton_proto/data/serving_status.proto\x1a\x35tecton_proto/data/internal_spark_cluster_status.proto\x1a\x1ftecton_proto/data/summary.proto\x1a\x30tecton_proto/data/saved_feature_data_frame.proto\x1a\"tecton_proto/data/onboarding.proto\x1a&tecton_proto/data/transformation.proto\x1a+tecton_proto/data/virtual_data_source.proto\x1a!tecton_proto/data/workspace.proto\x1a+tecton_proto/amplitude/client_logging.proto\x1a&tecton_proto/amplitude/amplitude.proto\x1a\'tecton_proto/validation/validator.proto\x1a\x39tecton_proto/materialization/materialization_states.proto\x1a\x30tecton_proto/materialization/spark_cluster.proto\"p\n\nJobsKeySet\x12\x39\n\nupdated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\"\xd0\x01\n\x11PaginationRequest\x12\x12\n\x04page\x18\x01 \x01(\rR\x04page\x12\x19\n\x08per_page\x18\x02 \x01(\rR\x07perPage\x12\x19\n\x08sort_key\x18\x03 \x01(\tR\x07sortKey\x12R\n\x0esort_direction\x18\x04 \x01(\x0e\x32+.tecton_proto.metadataservice.SortDirectionR\rsortDirection\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\"\xf0\x01\n\x12PaginationResponse\x12\x12\n\x04page\x18\x01 \x01(\rR\x04page\x12\x19\n\x08per_page\x18\x02 \x01(\rR\x07perPage\x12\x14\n\x05total\x18\x03 \x01(\rR\x05total\x12&\n\x0fnext_page_token\x18\x04 \x01(\tR\rnextPageToken\x12\x19\n\x08sort_key\x18\x05 \x01(\tR\x07sortKey\x12R\n\x0esort_direction\x18\x06 \x01(\x0e\x32+.tecton_proto.metadataservice.SortDirectionR\rsortDirection\"\x9a\x01\n\x18GetFeatureServiceRequest\x12+\n\x11service_reference\x18\x02 \x01(\tR\x10serviceReference\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\'\n\x02id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02idJ\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06\"a\n\x19GetFeatureServiceResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"<\n\x1cGetAllFeatureServicesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"m\n\x1dGetAllFeatureServicesResponse\x12L\n\x10\x66\x65\x61ture_services\x18\x01 \x03(\x0b\x32!.tecton_proto.data.FeatureServiceR\x0f\x66\x65\x61tureServices\"\xc7\x01\n\x1fGetFeatureServiceSummaryRequest\x12G\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tH\x00R\x12\x66\x65\x61tureServiceName\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\t\n\x07locator\"\x8c\x01\n GetFeatureServiceSummaryResponse\x12\x43\n\rgeneral_items\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.SummaryItemR\x0cgeneralItems\x12#\n\rvariant_names\x18\x03 \x03(\tR\x0cvariantNames\"f\n\"GetVirtualDataSourceSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"e\n#GetVirtualDataSourceSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"c\n\x1fGetTransformationSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"b\n GetTransformationSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"[\n\x17GetEntitySummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"Z\n\x18GetEntitySummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"\xd9\x01\n\x17GetServingStatusRequest\x12G\n\x12\x66\x65\x61ture_package_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61turePackageId\x12G\n\x12\x66\x65\x61ture_service_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x0e\n\x0crequest_type\"\xd6\x01\n\x1eGetFVServingStatusForFSRequest\x12\x45\n\x12\x66\x65\x61ture_service_id\x18\x02 \x02(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61tureServiceId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12O\n\npagination\x18\x04 \x01(\x0b\x32/.tecton_proto.metadataservice.PaginationRequestR\npagination\"\xe7\x01\n\x1fGetFVServingStatusForFSResponse\x12r\n\x1b\x66ull_serving_status_summary\x18\x01 \x01(\x0b\x32\x33.tecton_proto.data.FullFeatureServiceServingSummaryR\x18\x66ullServingStatusSummary\x12P\n\npagination\x18\x02 \x01(\x0b\x32\x30.tecton_proto.metadataservice.PaginationResponseR\npagination\"y\n\x18GetServingStatusResponse\x12]\n\x16serving_status_summary\x18\x05 \x01(\x0b\x32\'.tecton_proto.data.ServingStatusSummaryR\x14servingStatusSummary\"=\n\x1dGetAllFeatureFreshnessRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"s\n\x1eGetAllFeatureFreshnessResponse\x12Q\n\x12\x66reshness_statuses\x18\x01 \x03(\x0b\x32\".tecton_proto.data.FreshnessStatusR\x11\x66reshnessStatuses\"^\n\x1aGetFeatureFreshnessRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"l\n\x1bGetFeatureFreshnessResponse\x12M\n\x10\x66reshness_status\x18\x01 \x01(\x0b\x32\".tecton_proto.data.FreshnessStatusR\x0f\x66reshnessStatus\"`\n\x1cGetFeatureConsumptionRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"u\n\x1dGetFeatureConsumptionResponse\x12T\n\x10\x63onsumption_info\x18\x01 \x03(\x0b\x32).tecton_proto.consumption.ConsumptionInfoR\x0f\x63onsumptionInfo\"h\n\x1fGetMaterializationStatusRequest\x12\x45\n\x12\x66\x65\x61ture_package_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61turePackageId\"\x83\x01\n GetMaterializationStatusResponse\x12_\n\x16materialization_status\x18\x01 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\"V\n2GetAllMaterializationStatusInLiveWorkspacesRequest\x12 \n\x0c\x63ut_off_days\x18\x01 \x01(\x05R\ncutOffDays\"4\n\nCountRange\x12\x14\n\x05start\x18\x01 \x01(\rR\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\rR\x03\x65nd\"m\n\rDurationRange\x12/\n\x05start\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x05start\x12+\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x03\x65nd\"o\n\rDateTimeRange\x12\x30\n\x05start\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05start\x12,\n\x03\x65nd\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03\x65nd\"\x82\x06\n\x0eGetJobsRequest\x12\x1e\n\nworkspaces\x18\x01 \x03(\tR\nworkspaces\x12#\n\rfeature_views\x18\x02 \x03(\tR\x0c\x66\x65\x61tureViews\x12R\n\x08statuses\x18\x03 \x03(\x0e\x32\x36.tecton_proto.materialization.MaterializationTaskStateR\x08statuses\x12J\n\ncreated_at\x18\x06 \x01(\x0b\x32+.tecton_proto.metadataservice.DateTimeRangeR\tcreatedAt\x12\x43\n\ttask_type\x18\x04 \x03(\x0e\x32&.tecton_proto.materialization.TaskTypeR\x08taskType\x12K\n\x0cnum_attempts\x18\x05 \x01(\x0b\x32(.tecton_proto.metadataservice.CountRangeR\x0bnumAttempts\x12-\n\x12manually_triggered\x18\x07 \x01(\x08R\x11manuallyTriggered\x12G\n\x08\x64uration\x18\x08 \x01(\x0b\x32+.tecton_proto.metadataservice.DurationRangeR\x08\x64uration\x12Y\n\x12\x66\x65\x61ture_start_time\x18\n \x01(\x0b\x32+.tecton_proto.metadataservice.DateTimeRangeR\x10\x66\x65\x61tureStartTime\x12U\n\x10\x66\x65\x61ture_end_time\x18\x0b \x01(\x0b\x32+.tecton_proto.metadataservice.DateTimeRangeR\x0e\x66\x65\x61tureEndTime\x12O\n\npagination\x18\t \x01(\x0b\x32/.tecton_proto.metadataservice.PaginationRequestR\npagination\"\xc5\x01\n FeatureViewMaterializationStatus\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12_\n\x16materialization_status\x18\x03 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\"\xb5\x04\n\x10TaskWithAttempts\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12K\n\ttaskState\x18\x02 \x01(\x0e\x32-.tecton_proto.data.MaterializationStatusStateR\ttaskState\x12_\n\x16materialization_status\x18\x03 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\x12\x30\n\x07task_id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x06taskId\x12\x43\n\ttask_type\x18\x08 \x01(\x0e\x32&.tecton_proto.materialization.TaskTypeR\x08taskType\x12*\n\x11\x66\x65\x61ture_view_name\x18\x05 \x01(\tR\x0f\x66\x65\x61tureViewName\x12H\n\x12\x66\x65\x61ture_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x66\x65\x61tureStartTime\x12\x44\n\x10\x66\x65\x61ture_end_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x66\x65\x61tureEndTime\"\xc5\x01\n3GetAllMaterializationStatusInLiveWorkspacesResponse\x12\x8d\x01\n#feature_view_materialization_status\x18\x01 \x03(\x0b\x32>.tecton_proto.metadataservice.FeatureViewMaterializationStatusR featureViewMaterializationStatus\"\xc1\x01\n\x0fGetJobsResponse\x12\\\n\x11tasksWithAttempts\x18\x01 \x03(\x0b\x32..tecton_proto.metadataservice.TaskWithAttemptsR\x11tasksWithAttempts\x12P\n\npagination\x18\x02 \x01(\x0b\x32\x30.tecton_proto.metadataservice.PaginationResponseR\npagination\"\xa0\x01\n$ForceRetryMaterializationTaskRequest\x12O\n\x17materialization_task_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x15materializationTaskId\x12\'\n\x0f\x61llow_overwrite\x18\x02 \x01(\x08R\x0e\x61llowOverwrite\"L\n%ForceRetryMaterializationTaskResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\".\n\x0eGetFcosRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"W\n\x0fGetFcosResponse\x12\x44\n\rfco_container\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"a\n\x15GetSparkConfigRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\"\xb0\x01\n\x16GetSparkConfigResponse\x12I\n\x0c\x62\x61tch_config\x18\x01 \x01(\x0b\x32&.tecton_proto.spark_common.ClusterInfoR\x0b\x62\x61tchConfig\x12K\n\rstream_config\x18\x02 \x01(\x0b\x32&.tecton_proto.spark_common.ClusterInfoR\x0cstreamConfig\"t\n(GetMetricAndExpectationDefinitionRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\"\xe4\x02\n)GetMetricAndExpectationDefinitionResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x36\n\x07metrics\x18\x03 \x03(\x0b\x32\x1c.tecton_proto.dataobs.MetricR\x07metrics\x12[\n\x14\x66\x65\x61ture_expectations\x18\x04 \x03(\x0b\x32(.tecton_proto.dataobs.FeatureExpectationR\x13\x66\x65\x61tureExpectations\x12X\n\x13metric_expectations\x18\x05 \x03(\x0b\x32\'.tecton_proto.dataobs.MetricExpectationR\x12metricExpectations\"\x91\x01\n\x15GetFeatureViewRequest\x12+\n\x11version_specifier\x18\x01 \x01(\tR\x10versionSpecifier\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\'\n\x02id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02idJ\x04\x08\x05\x10\x06\"^\n\x16GetFeatureViewResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"`\n\x1cGetFeatureViewSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"_\n\x1dGetFeatureViewSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"R\n\x18QueryFeatureViewsRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceJ\x04\x08\x05\x10\x06\"a\n\x19QueryFeatureViewsResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"{\n4GetMaterializingFeatureViewsInLiveWorkspacesResponse\x12\x43\n\rfeature_views\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.FeatureViewR\x0c\x66\x65\x61tureViews\"\xba\x01\n\x1bGetVirtualDataSourceRequest\x12N\n\x16virtual_data_source_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x13virtualDataSourceId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x11\n\x0fidentifier_typeJ\x04\x08\x05\x10\x06\"d\n\x1cGetVirtualDataSourceResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"?\n\x1fGetAllVirtualDataSourcesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"z\n GetAllVirtualDataSourcesResponse\x12V\n\x14virtual_data_sources\x18\x01 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceR\x12virtualDataSources\"\x97\x01\n\x10GetEntityRequest\x12\x36\n\tentity_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x08\x65ntityId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x11\n\x0fidentifier_typeJ\x04\x08\x05\x10\x06\"Y\n\x11GetEntityResponse\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"5\n\x15GetAllEntitiesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"O\n\x16GetAllEntitiesResponse\x12\x35\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.tecton_proto.data.EntityR\x08\x65ntities\"\xaf\x01\n\x18GetTransformationRequest\x12\x46\n\x11transformation_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10transformationId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x04 \x01(\tR\tworkspaceB\x11\n\x0fidentifier_typeJ\x04\x08\x05\x10\x06\"g\n\x19GetTransformationResponse\x12\x44\n\rfco_container\x18\x03 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainerJ\x04\x08\x01\x10\x02\"<\n\x1cGetAllTransformationsRequest\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"r\n\x1dGetAllTransformationsResponse\x12K\n\x0ftransformations\x18\x02 \x03(\x0b\x32!.tecton_proto.data.TransformationR\x0ftransformationsJ\x04\x08\x01\x10\x02\"B\n\x17\x46indFcoWorkspaceRequest\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\"8\n\x18\x46indFcoWorkspaceResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"z\n\x17IngestClientLogsRequest\x12_\n\x15sdk_method_invocation\x18\x01 \x01(\x0b\x32+.tecton_proto.amplitude.SDKMethodInvocationR\x13sdkMethodInvocation\"v\n\x16IngestAnalyticsRequest\x12>\n\x06\x65vents\x18\x01 \x03(\x0b\x32&.tecton_proto.amplitude.AmplitudeEventR\x06\x65vents\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\xbf\x01\n\x15NewStateUpdateRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32%.tecton_proto.data.StateUpdateRequestR\x07request\x12\x31\n\x15\x62locking_dry_run_mode\x18\x02 \x01(\x08R\x12\x62lockingDryRunMode\x12\x32\n\x15\x65nable_eager_response\x18\x03 \x01(\x08R\x13\x65nableEagerResponse\"\xfd\x01\n\x17NewStateUpdateRequestV2\x12?\n\x07request\x18\x01 \x01(\x0b\x32%.tecton_proto.data.StateUpdateRequestR\x07request\x12\x31\n\x15\x62locking_dry_run_mode\x18\x02 \x01(\x08R\x12\x62lockingDryRunMode\x12\x32\n\x15\x65nable_eager_response\x18\x03 \x01(\x08R\x13\x65nableEagerResponse\x12\x19\n\x08no_color\x18\x04 \x01(\x08R\x07noColor\x12\x1f\n\x0bjson_output\x18\x05 \x01(\x08R\njsonOutput\"\xe7\x01\n\x16NewStateUpdateResponse\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12:\n\x1asigned_url_for_repo_upload\x18\x02 \x01(\tR\x16signedUrlForRepoUpload\x12]\n\x0e\x65\x61ger_response\x18\x03 \x01(\x0b\x32\x36.tecton_proto.metadataservice.QueryStateUpdateResponseR\reagerResponse\"\xeb\x01\n\x18NewStateUpdateResponseV2\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12:\n\x1asigned_url_for_repo_upload\x18\x02 \x01(\tR\x16signedUrlForRepoUpload\x12_\n\x0e\x65\x61ger_response\x18\x03 \x01(\x0b\x32\x38.tecton_proto.metadataservice.QueryStateUpdateResponseV2R\reagerResponse\"k\n\x17QueryStateUpdateRequest\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\xa9\x01\n\x19QueryStateUpdateRequestV2\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\x12\x19\n\x08no_color\x18\x03 \x01(\x08R\x07noColor\x12\x1f\n\x0bjson_output\x18\x04 \x01(\x08R\njsonOutput\"\xd4\x02\n\x18QueryStateUpdateResponse\x12\x14\n\x05ready\x18\x01 \x01(\x08R\x05ready\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x12\x31\n\x14recreates_suppressed\x18\x07 \x01(\x08R\x13recreatesSuppressed\x12P\n\x11validation_result\x18\x04 \x01(\x0b\x32#.tecton_proto.data.ValidationResultR\x10validationResult\x12\x39\n\ndiff_items\x18\x05 \x03(\x0b\x32\x1a.tecton_proto.data.FcoDiffR\tdiffItems\x12\x32\n\x15latest_status_message\x18\x06 \x01(\tR\x13latestStatusMessage\"\xe9\x02\n\x1aQueryStateUpdateResponseV2\x12\x14\n\x05ready\x18\x01 \x01(\x08R\x05ready\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x12\x32\n\x15latest_status_message\x18\x06 \x01(\tR\x13latestStatusMessage\x12R\n\x11validation_errors\x18\x08 \x01(\x0b\x32#.tecton_proto.data.ValidationResultH\x00R\x10validationErrors\x12_\n\x16successful_plan_output\x18\t \x01(\x0b\x32\'.tecton_proto.data.SuccessfulPlanOutputH\x00R\x14successfulPlanOutputB\n\n\x08responseJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"T\n GetStateUpdatePlanSummaryRequest\x12\x30\n\x07plan_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x06planId\"b\n!GetStateUpdatePlanSummaryResponse\x12=\n\x04plan\x18\x01 \x01(\x0b\x32).tecton_proto.data.StateUpdatePlanSummaryR\x04plan\"p\n\x17\x41pplyStateUpdateRequest\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12!\n\napplied_by\x18\x02 \x01(\tB\x02\x18\x01R\tappliedBy\"\x1a\n\x18\x41pplyStateUpdateResponse\"\xb2\x01\n\x12GetConfigsResponse\x12^\n\nkey_values\x18\x01 \x03(\x0b\x32?.tecton_proto.metadataservice.GetConfigsResponse.KeyValuesEntryR\tkeyValues\x1a<\n\x0eKeyValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc2\x01\n\x1aGetGlobalsForWebUIResponse\x12\x66\n\nkey_values\x18\x01 \x03(\x0b\x32G.tecton_proto.metadataservice.GetGlobalsForWebUIResponse.KeyValuesEntryR\tkeyValues\x1a<\n\x0eKeyValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"N\n\x18GetStateUpdateLogRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"Z\n\x19GetStateUpdateLogResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.tecton_proto.data.StateUpdateEntryR\x07\x65ntries\"R\n\x15GetRestoreInfoRequest\x12\x1b\n\tcommit_id\x18\x01 \x01(\tR\x08\x63ommitId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\x96\x01\n\x16GetRestoreInfoResponse\x12>\n\x1csigned_url_for_repo_download\x18\x01 \x01(\tR\x18signedUrlForRepoDownload\x12\x1b\n\tcommit_id\x18\x02 \x01(\tR\x08\x63ommitId\x12\x1f\n\x0bsdk_version\x18\x03 \x01(\tR\nsdkVersion\"\x93\x01\n\x16\x43reateWorkspaceRequest\x12%\n\x0eworkspace_name\x18\x02 \x01(\tR\rworkspaceName\x12L\n\x0c\x63\x61pabilities\x18\x03 \x01(\x0b\x32(.tecton_proto.data.WorkspaceCapabilitiesR\x0c\x63\x61pabilitiesJ\x04\x08\x01\x10\x02\"6\n\x16\x44\x65leteWorkspaceRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"2\n\x17IntrospectApiKeyRequest\x12\x17\n\x07\x61pi_key\x18\x01 \x01(\tR\x06\x61piKey\"\xcb\x01\n\x18IntrospectApiKeyResponse\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1d\n\ncreated_by\x18\x03 \x01(\tR\tcreatedBy\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x19\n\x08is_admin\x18\x05 \x01(\x08R\x07isAdmin\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\"R\n\x13\x43reateApiKeyRequest\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x19\n\x08is_admin\x18\x02 \x01(\x08R\x07isAdmin\"Q\n\x14\x43reateApiKeyResponse\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\">\n\x13\x44\x65leteApiKeyRequest\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\"?\n\x12ListApiKeysRequest\x12)\n\x10include_archived\x18\x01 \x01(\x08R\x0fincludeArchived\"Q\n\x13ListApiKeysResponse\x12:\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x1f.tecton_proto.data.TectonApiKeyR\x07\x61piKeys\"\xe4\x01\n\x0eServiceAccount\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\tis_active\x18\x04 \x01(\x08R\x08isActive\x12\x36\n\x07\x63reator\x18\x05 \x01(\x0b\x32\x1c.tecton_proto.auth.PrincipalR\x07\x63reator\x12\x37\n\x05owner\x18\x06 \x01(\x0b\x32!.tecton_proto.auth.PrincipalBasicR\x05owner\"S\n\x1b\x43reateServiceAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"\x9a\x01\n\x1c\x43reateServiceAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\tis_active\x18\x04 \x01(\x08R\x08isActive\x12\x17\n\x07\x61pi_key\x18\x05 \x01(\tR\x06\x61piKey\"E\n\x19GetServiceAccountsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\x10\n\x03ids\x18\x02 \x03(\tR\x03ids\"u\n\x1aGetServiceAccountsResponse\x12W\n\x10service_accounts\x18\x01 \x03(\x0b\x32,.tecton_proto.metadataservice.ServiceAccountR\x0fserviceAccounts\"\x80\x01\n\x1bUpdateServiceAccountRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\tis_active\x18\x04 \x01(\x08R\x08isActive\"\x81\x01\n\x1cUpdateServiceAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\tis_active\x18\x04 \x01(\x08R\x08isActive\"-\n\x1b\x44\x65leteServiceAccountRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1e\n\x1c\x44\x65leteServiceAccountResponse\"\x17\n\x15ListWorkspacesRequest\"V\n\x16ListWorkspacesResponse\x12<\n\nworkspaces\x18\x01 \x03(\x0b\x32\x1c.tecton_proto.data.WorkspaceR\nworkspaces\"<\n\x13GetWorkspaceRequest\x12%\n\x0eworkspace_name\x18\x01 \x01(\tR\rworkspaceName\"R\n\x14GetWorkspaceResponse\x12:\n\tworkspace\x18\x01 \x01(\x0b\x32\x1c.tecton_proto.data.WorkspaceR\tworkspace\"\x93\x03\n\"CreateSavedFeatureDataFrameRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tworkspace\x18\x07 \x01(\tR\tworkspace\x12G\n\x12\x66\x65\x61ture_package_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61turePackageId\x12G\n\x12\x66\x65\x61ture_service_id\x18\x03 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x31\n\x15join_key_column_names\x18\x04 \x03(\tR\x12joinKeyColumnNames\x12\x32\n\x15timestamp_column_name\x18\x05 \x01(\tR\x13timestampColumnName\x12\x38\n\x06schema\x18\x06 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x06schemaB\x08\n\x06source\"\x87\x01\n#CreateSavedFeatureDataFrameResponse\x12`\n\x17saved_feature_dataframe\x18\x01 \x01(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x15savedFeatureDataframe\"{\n#ArchiveSavedFeatureDataFrameRequest\x12T\n\x1asaved_feature_dataframe_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x17savedFeatureDataframeId\"&\n$ArchiveSavedFeatureDataFrameResponse\"\xe7\x01\n\x1fGetSavedFeatureDataFrameRequest\x12\x41\n\x1csaved_feature_dataframe_name\x18\x01 \x01(\tH\x00R\x19savedFeatureDataframeName\x12V\n\x1asaved_feature_dataframe_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x17savedFeatureDataframeId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x0b\n\treference\"\xa5\x01\n\x1bGetClusterAdminInfoResponse\x12&\n\x0f\x63\x61ller_is_admin\x18\x01 \x01(\x08R\rcallerIsAdmin\x12-\n\x05users\x18\x02 \x03(\x0b\x32\x17.tecton_proto.data.UserR\x05users\x12/\n\x06\x61\x64mins\x18\x03 \x03(\x0b\x32\x17.tecton_proto.data.UserR\x06\x61\x64mins\";\n\x18\x43reateClusterUserRequest\x12\x1f\n\x0blogin_email\x18\x01 \x01(\tR\nloginEmail\"@\n\x19\x43reateClusterUserResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"3\n\x18\x44\x65leteClusterUserRequest\x12\x17\n\x07okta_id\x18\x01 \x01(\tR\x06oktaId\"@\n\x19\x44\x65leteClusterUserResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"\xe2\x01\n\x18\x43lusterUserActionRequest\x12\x17\n\x07okta_id\x18\x01 \x01(\tR\x06oktaId\x12\x38\n\x17resend_activation_email\x18\x02 \x01(\x08H\x00R\x15resendActivationEmail\x12!\n\x0bunlock_user\x18\x03 \x01(\x08H\x00R\nunlockUser\x12!\n\x0bgrant_admin\x18\x04 \x01(\x08H\x00R\ngrantAdmin\x12#\n\x0crevoke_admin\x18\x05 \x01(\x08H\x00R\x0brevokeAdminB\x08\n\x06\x61\x63tion\"@\n\x19\x43lusterUserActionResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"\x84\x01\n GetSavedFeatureDataFrameResponse\x12`\n\x17saved_feature_dataframe\x18\x01 \x01(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x15savedFeatureDataframe\"C\n#GetAllSavedFeatureDataFramesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"\x8a\x01\n$GetAllSavedFeatureDataFramesResponse\x12\x62\n\x18saved_feature_dataframes\x18\x01 \x03(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x16savedFeatureDataframes\"\x9c\x01\n\x16IngestDataframeRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\x12\x17\n\x07\x64\x66_path\x18\x02 \x01(\tR\x06\x64\x66Path\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\"\x19\n\x17IngestDataframeResponse\"o\n GetNewIngestDataframeInfoRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\"t\n!GetNewIngestDataframeInfoResponse\x12\x17\n\x07\x64\x66_path\x18\x01 \x01(\tR\x06\x64\x66Path\x12\x36\n\x18signed_url_for_df_upload\x18\x02 \x01(\tR\x14signedUrlForDfUpload\"\x88\x01\n!GetUserDeploymentSettingsResponse\x12\x63\n\x18user_deployment_settings\x18\x01 \x01(\x0b\x32).tecton_proto.data.UserDeploymentSettingsR\x16userDeploymentSettings\"\xc5\x01\n#UpdateUserDeploymentSettingsRequest\x12\x63\n\x18user_deployment_settings\x18\x01 \x01(\x0b\x32).tecton_proto.data.UserDeploymentSettingsR\x16userDeploymentSettings\x12\x39\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\tfieldMask\"e\n$UpdateUserDeploymentSettingsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"n\n%GetInternalSparkClusterStatusResponse\x12\x45\n\x06status\x18\x01 \x01(\x0b\x32-.tecton_proto.data.InternalSparkClusterStatusR\x06status\"k\n\x1cGetDeleteEntitiesInfoRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\"\xca\x01\n\x1dGetDeleteEntitiesInfoResponse\x12\x17\n\x07\x64\x66_path\x18\x01 \x01(\tR\x06\x64\x66Path\x12\x43\n\x1fsigned_url_for_df_upload_online\x18\x03 \x01(\tR\x1asignedUrlForDfUploadOnline\x12\x45\n signed_url_for_df_upload_offline\x18\x04 \x01(\tR\x1bsignedUrlForDfUploadOfflineJ\x04\x08\x02\x10\x03\"\xf3\x01\n\x15\x44\x65leteEntitiesRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12\x31\n\x15online_join_keys_path\x18\x02 \x01(\tR\x12onlineJoinKeysPath\x12\x33\n\x16offline_join_keys_path\x18\x03 \x01(\tR\x13offlineJoinKeysPath\x12\x16\n\x06online\x18\x04 \x01(\x08R\x06online\x12\x18\n\x07offline\x18\x05 \x01(\x08R\x07offline\"\x18\n\x16\x44\x65leteEntitiesResponse\"\xf9\x01\n\x16GetHiveMetadataRequest\x12S\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32;.tecton_proto.metadataservice.GetHiveMetadataRequest.ActionR\x06\x61\x63tion\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x14\n\x05table\x18\x03 \x01(\tR\x05table\"X\n\x06\x41\x63tion\x12\x19\n\x15\x41\x43TION_LIST_DATABASES\x10\x00\x12\x16\n\x12\x41\x43TION_LIST_TABLES\x10\x01\x12\x1b\n\x17\x41\x43TION_GET_TABLE_SCHEMA\x10\x02\"\xd1\x02\n\x17GetHiveMetadataResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\x12\x41\n\tdatabases\x18\x03 \x01(\x0b\x32!.tecton_proto.data.ListHiveResultH\x00R\tdatabases\x12;\n\x06tables\x18\x04 \x01(\x0b\x32!.tecton_proto.data.ListHiveResultH\x00R\x06tables\x12=\n\x07\x63olumns\x18\x05 \x01(\x0b\x32!.tecton_proto.data.ListHiveResultH\x00R\x07\x63olumns\x12.\n\x13\x64\x65\x62ug_error_message\x18\x06 \x01(\tR\x11\x64\x65\x62ugErrorMessageB\x08\n\x06result\"K\n\x16GetFileMetadataRequest\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12\x1f\n\x0b\x66ile_format\x18\x02 \x01(\tR\nfileFormat\"\xab\x01\n\x17GetFileMetadataResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\x12!\n\x0c\x63olumn_names\x18\x03 \x03(\tR\x0b\x63olumnNames\x12.\n\x13\x64\x65\x62ug_error_message\x18\x04 \x01(\tR\x11\x64\x65\x62ugErrorMessage\"R\n\x13ValidateFcosRequest\x12\x35\n\x08\x66\x63o_args\x18\x02 \x03(\x0b\x32\x1a.tecton_proto.args.FcoArgsR\x07\x66\x63oArgsJ\x04\x08\x01\x10\x02\"\xe6\x01\n\x14ValidateFcosResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12P\n\x11validation_result\x18\x02 \x01(\x0b\x32#.tecton_proto.data.ValidationResultR\x10validationResult\x12\x32\n\x15\x64isplay_error_message\x18\x04 \x01(\tR\x13\x64isplayErrorMessage\x12.\n\x13\x64\x65\x62ug_error_message\x18\x03 \x01(\tR\x11\x64\x65\x62ugErrorMessage\"\x95\x01\n\x17ValidateLocalFcoRequest\x12Y\n\x12validation_request\x18\x01 \x01(\x0b\x32*.tecton_proto.validation.ValidationRequestR\x11validationRequest\x12\x1f\n\x0bsdk_version\x18\x02 \x01(\tR\nsdkVersion\"\x9c\x01\n\x18ValidateLocalFcoResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12P\n\x11validation_result\x18\x02 \x01(\x0b\x32#.tecton_proto.data.ValidationResultR\x10validationResult\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\":\n\x1aGetOnboardingStatusRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"\x9c\x02\n\x1bGetOnboardingStatusResponse\x12N\n\x0esetup_platform\x18\x03 \x01(\x0e\x32\'.tecton_proto.data.OnboardingStatusEnumR\rsetupPlatform\x12W\n\x13\x63reate_feature_view\x18\x01 \x01(\x0e\x32\'.tecton_proto.data.OnboardingStatusEnumR\x11\x63reateFeatureView\x12T\n\x11\x66inish_onboarding\x18\x02 \x01(\x0e\x32\'.tecton_proto.data.OnboardingStatusEnumR\x10\x66inishOnboarding\"]\n\x1aSetOnboardingStatusRequest\x12?\n\x06status\x18\x01 \x01(\x0e\x32\'.tecton_proto.data.OnboardingStatusEnumR\x06status\"\x92\x01\n\"GetDataPlatformSetupStatusResponse\x12&\n\x0esetupCompleted\x18\x01 \x01(\x08R\x0esetupCompleted\x12\x44\n\x05tasks\x18\x02 \x03(\x0b\x32..tecton_proto.data.DataPlatformSetupTaskStatusR\x05tasks\"7\n#GetRetrieveFeaturesNotebookResponse\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"i\n\x1dGetObservabilityConfigRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\"\xa5\x01\n\x1eGetObservabilityConfigResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x39\n\x19is_dataobs_metric_enabled\x18\x03 \x01(\x08R\x16isDataobsMetricEnabled\"\x93\x02\n\x12QueryMetricRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x41\n\x0bmetric_type\x18\x03 \x01(\x0e\x32 .tecton_proto.dataobs.MetricTypeR\nmetricType\x12\x39\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\"\xf5\x03\n\x13QueryMetricResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x41\n\x0bmetric_type\x18\x03 \x01(\x0e\x32 .tecton_proto.dataobs.MetricTypeR\nmetricType\x12V\n\x1ametric_data_point_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17metricDataPointInterval\x12H\n\x12\x61ligned_start_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x61lignedStartTime\x12\x44\n\x10\x61ligned_end_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x61lignedEndTime\x12\x46\n\x0bmetric_data\x18\x04 \x03(\x0b\x32%.tecton_proto.dataobs.MetricDataPointR\nmetricData\x12!\n\x0c\x63olumn_names\x18\x06 \x03(\tR\x0b\x63olumnNames\"\x89\x01\n\"GetFeatureValidationHistoryRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x19\n\x05limit\x18\x03 \x01(\x05:\x03\x31\x30\x30R\x05limit\"\xb2\x01\n#GetFeatureValidationHistoryResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12*\n\x11\x66\x65\x61ture_view_name\x18\x02 \x01(\tR\x0f\x66\x65\x61tureViewName\x12\x41\n\x07results\x18\x03 \x03(\x0b\x32\'.tecton_proto.dataobs.ExpectationResultR\x07results\"\x80\x04\n!GetFeatureValidationResultRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12N\n\x15validation_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validationStartTime\x12J\n\x13validation_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11validationEndTime\x12\x39\n\x19\x66ilter_feature_view_names\x18\x04 \x03(\tR\x16\x66ilterFeatureViewNames\x12\x38\n\x18\x66ilter_expectation_names\x18\x05 \x03(\tR\x16\x66ilterExpectationNames\x12[\n\x13\x66ilter_result_types\x18\x06 \x03(\x0e\x32+.tecton_proto.dataobs.ExpectationResultEnumR\x11\x66ilterResultTypes\x12O\n\npagination\x18\x07 \x01(\x0b\x32/.tecton_proto.metadataservice.PaginationRequestR\npagination\"\x8c\x01\n\"GetFeatureValidationResultResponse\x12#\n\rtotal_results\x18\x01 \x01(\x05R\x0ctotalResults\x12\x41\n\x07results\x18\x02 \x03(\x0b\x32\'.tecton_proto.dataobs.ExpectationResultR\x07results\"\xde\x01\n\"GetFeatureValidationSummaryRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12N\n\x15validation_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validationStartTime\x12J\n\x13validation_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11validationEndTime\"\xba\x02\n#GetFeatureValidationSummaryResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\x12N\n\x15validation_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validationStartTime\x12J\n\x13validation_end_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11validationEndTime\x12Y\n\x11workspace_summary\x18\x04 \x01(\x0b\x32,.tecton_proto.dataobs.WorkspaceResultSummaryR\x10workspaceSummary\"6\n\x0eGetUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\"C\n\x0fGetUserResponse\x12\x30\n\x04user\x18\x01 \x01(\x0b\x32\x1c.tecton_proto.auth.UserBasicR\x04user\"\x1f\n\x1dGetFeatureServerConfigRequest\"\x90\x01\n\x1eGetFeatureServerConfigResponse\x12\"\n\x0c\x63urrentCount\x18\x01 \x01(\rR\x0c\x63urrentCount\x12&\n\x0e\x61vailableCount\x18\x02 \x01(\rR\x0e\x61vailableCount\x12\"\n\x0c\x64\x65siredCount\x18\x03 \x01(\rR\x0c\x64\x65siredCount\"5\n\x1dSetFeatureServerConfigRequest\x12\x14\n\x05\x63ount\x18\x01 \x01(\rR\x05\x63ount*>\n\rSortDirection\x12\x10\n\x0cSORT_UNKNOWN\x10\x00\x12\x0c\n\x08SORT_ASC\x10\x01\x12\r\n\tSORT_DESC\x10\x02\x32\xac\x97\x01\n\x0fMetadataService\x12\xec\x01\n\x11GetFeatureService\x12\x36.tecton_proto.metadataservice.GetFeatureServiceRequest\x1a\x37.tecton_proto.metadataservice.GetFeatureServiceResponse\"f\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/get-feature-service:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xfd\x01\n\x15GetAllFeatureServices\x12:.tecton_proto.metadataservice.GetAllFeatureServicesRequest\x1a;.tecton_proto.metadataservice.GetAllFeatureServicesResponse\"k\x82\xd3\xe4\x93\x02\x32\"-/v1/metadata-service/get-all-feature-services:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x98\x02\n\x18GetFeatureServiceSummary\x12=.tecton_proto.metadataservice.GetFeatureServiceSummaryRequest\x1a>.tecton_proto.metadataservice.GetFeatureServiceSummaryResponse\"}\x82\xd3\xe4\x93\x02\x35\"0/v1/metadata-service/get-feature-service-summary:\x01*\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\xf7\x01\n\x10GetServingStatus\x12\x35.tecton_proto.metadataservice.GetServingStatusRequest\x1a\x36.tecton_proto.metadataservice.GetServingStatusResponse\"t\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-service/get-serving-status:\x01*\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\x96\x02\n\x17GetFVServingStatusForFS\x12<.tecton_proto.metadataservice.GetFVServingStatusForFSRequest\x1a=.tecton_proto.metadataservice.GetFVServingStatusForFSResponse\"~\x82\xd3\xe4\x93\x02\x36\"1/v1/metadata-service/get-fv-serving-status-for-fs:\x01*\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\x90\x02\n\x16GetAllFeatureFreshness\x12;.tecton_proto.metadataservice.GetAllFeatureFreshnessRequest\x1a<.tecton_proto.metadataservice.GetAllFeatureFreshnessResponse\"{\x82\xd3\xe4\x93\x02\x33\"./v1/metadata-service/get-all-feature-freshness:\x01*\xa2\xbc\xe6\xc0\x05<\x1a\r\x08\x01\x12\tworkspace*+tecton/workspace#read_materialization_state\x12\x90\x02\n\x13GetFeatureFreshness\x12\x38.tecton_proto.metadataservice.GetFeatureFreshnessRequest\x1a\x39.tecton_proto.metadataservice.GetFeatureFreshnessResponse\"\x83\x01\x82\xd3\xe4\x93\x02/\"*/v1/metadata-service/get-feature-freshness:\x01*\xa2\xbc\xe6\xc0\x05H\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*+tecton/workspace#read_materialization_state\x12\xdd\x01\n\x18GetMaterializationStatus\x12=.tecton_proto.metadataservice.GetMaterializationStatusRequest\x1a>.tecton_proto.metadataservice.GetMaterializationStatusResponse\"B\x82\xd3\xe4\x93\x02\x34\"//v1/metadata-service/get-materialization-status:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xac\x02\n+GetAllMaterializationStatusInLiveWorkspaces\x12P.tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesRequest\x1aQ.tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesResponse\"X\x82\xd3\xe4\x93\x02J\"E/v1/metadata-service/get-all-materialization-status-in-live-workspace:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\x94\x01\n\x07GetJobs\x12,.tecton_proto.metadataservice.GetJobsRequest\x1a-.tecton_proto.metadataservice.GetJobsResponse\",\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/metadata-service/jobs:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xf2\x01\n\x1d\x46orceRetryMaterializationTask\x12\x42.tecton_proto.metadataservice.ForceRetryMaterializationTaskRequest\x1a\x43.tecton_proto.metadataservice.ForceRetryMaterializationTaskResponse\"H\x82\xd3\xe4\x93\x02:\"5/v1/metadata-service/force-retry-materialization-task:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xe0\x01\n\x0eGetSparkConfig\x12\x33.tecton_proto.metadataservice.GetSparkConfigRequest\x1a\x34.tecton_proto.metadataservice.GetSparkConfigResponse\"c\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/get-spark-config:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xae\x02\n!GetMetricAndExpectationDefinition\x12\x46.tecton_proto.metadataservice.GetMetricAndExpectationDefinitionRequest\x1aG.tecton_proto.metadataservice.GetMetricAndExpectationDefinitionResponse\"x\x82\xd3\xe4\x93\x02?\":/v1/metadata-service/get-metric-and-expectation-definition:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xe0\x01\n\x0eGetFeatureView\x12\x33.tecton_proto.metadataservice.GetFeatureViewRequest\x1a\x34.tecton_proto.metadataservice.GetFeatureViewResponse\"c\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/get-feature-view:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xf0\x01\n,GetMaterializingFeatureViewsInLiveWorkspaces\x12\x16.google.protobuf.Empty\x1aR.tecton_proto.metadataservice.GetMaterializingFeatureViewsInLiveWorkspacesResponse\"T\x82\xd3\xe4\x93\x02\x46\"A/v1/metadata-service/get-materializing-features-in-live-workspace:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xec\x01\n\x11QueryFeatureViews\x12\x36.tecton_proto.metadataservice.QueryFeatureViewsRequest\x1a\x37.tecton_proto.metadataservice.QueryFeatureViewsResponse\"f\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/query-feature-views:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x99\x02\n\x15GetFeatureViewSummary\x12:.tecton_proto.metadataservice.GetFeatureViewSummaryRequest\x1a;.tecton_proto.metadataservice.GetFeatureViewSummaryResponse\"\x86\x01\x82\xd3\xe4\x93\x02\x32\"-/v1/metadata-package/get-feature-view-summary:\x01*\xa2\xbc\xe6\xc0\x05H\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*+tecton/workspace#read_materialization_state\x12\x8d\x02\n\x15GetFeatureConsumption\x12:.tecton_proto.metadataservice.GetFeatureConsumptionRequest\x1a;.tecton_proto.metadataservice.GetFeatureConsumptionResponse\"{\x82\xd3\xe4\x93\x02\x36\"1/v1/metadata-service/get-feature-view-consumption:\x01*\xa2\xbc\xe6\xc0\x05\x39\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*\x1ctecton/workspace#read_config\x12\xf9\x01\n\x14GetVirtualDataSource\x12\x39.tecton_proto.metadataservice.GetVirtualDataSourceRequest\x1a:.tecton_proto.metadataservice.GetVirtualDataSourceResponse\"j\x82\xd3\xe4\x93\x02\x31\",/v1/metadata-service/get-virtual-data-source:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x8a\x02\n\x18GetAllVirtualDataSources\x12=.tecton_proto.metadataservice.GetAllVirtualDataSourcesRequest\x1a>.tecton_proto.metadataservice.GetAllVirtualDataSourcesResponse\"o\x82\xd3\xe4\x93\x02\x36\"1/v1/metadata-service/get-all-virtual-data-sources:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x90\x01\n\x10IngestClientLogs\x12\x35.tecton_proto.metadataservice.IngestClientLogsRequest\x1a\x16.google.protobuf.Empty\"-\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xbe\x01\n\x0fIngestAnalytics\x12\x34.tecton_proto.metadataservice.IngestAnalyticsRequest\x1a\x16.google.protobuf.Empty\"]\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/ingest-analytics:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xa2\x02\n\x1bGetVirtualDataSourceSummary\x12@.tecton_proto.metadataservice.GetVirtualDataSourceSummaryRequest\x1a\x41.tecton_proto.metadataservice.GetVirtualDataSourceSummaryResponse\"~\x82\xd3\xe4\x93\x02\x39\"4/v1/metadata-service/get-virtual-data-source-summary:\x01*\xa2\xbc\xe6\xc0\x05\x39\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*\x1ctecton/workspace#read_config\x12\xc3\x01\n\x07GetFcos\x12,.tecton_proto.metadataservice.GetFcosRequest\x1a-.tecton_proto.metadataservice.GetFcosResponse\"[\x82\xd3\xe4\x93\x02\"\"\x1d/v1/metadata-service/get-fcos:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xa1\x01\n\tGetEntity\x12..tecton_proto.metadataservice.GetEntityRequest\x1a/.tecton_proto.metadataservice.GetEntityResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xe0\x01\n\x0eGetAllEntities\x12\x33.tecton_proto.metadataservice.GetAllEntitiesRequest\x1a\x34.tecton_proto.metadataservice.GetAllEntitiesResponse\"c\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/get-all-entities:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xf4\x01\n\x10GetEntitySummary\x12\x35.tecton_proto.metadataservice.GetEntitySummaryRequest\x1a\x36.tecton_proto.metadataservice.GetEntitySummaryResponse\"q\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-package/get-entity-summary:\x01*\xa2\xbc\xe6\xc0\x05\x39\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*\x1ctecton/workspace#read_config\x12\xeb\x01\n\x11GetTransformation\x12\x36.tecton_proto.metadataservice.GetTransformationRequest\x1a\x37.tecton_proto.metadataservice.GetTransformationResponse\"e\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-service/get-transformation:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xfc\x01\n\x15GetAllTransformations\x12:.tecton_proto.metadataservice.GetAllTransformationsRequest\x1a;.tecton_proto.metadataservice.GetAllTransformationsResponse\"j\x82\xd3\xe4\x93\x02\x31\",/v1/metadata-service/get-all-transformations:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x94\x02\n\x18GetTransformationSummary\x12=.tecton_proto.metadataservice.GetTransformationSummaryRequest\x1a>.tecton_proto.metadataservice.GetTransformationSummaryResponse\"y\x82\xd3\xe4\x93\x02\x34\"//v1/metadata-package/get-transformation-summary:\x01*\xa2\xbc\xe6\xc0\x05\x39\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace*\x1ctecton/workspace#read_config\x12\xbd\x01\n\x10\x46indFcoWorkspace\x12\x35.tecton_proto.metadataservice.FindFcoWorkspaceRequest\x1a\x36.tecton_proto.metadataservice.FindFcoWorkspaceResponse\":\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-service/find-fco-workspace:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb8\x01\n\x0eNewStateUpdate\x12\x33.tecton_proto.metadataservice.NewStateUpdateRequest\x1a\x34.tecton_proto.metadataservice.NewStateUpdateResponse\";\xa2\xbc\xe6\xc0\x05\x35\x1a\x15\x08\x01\x12\x11request.workspace*\x1ctecton/workspace#read_config\x12\xbe\x01\n\x10NewStateUpdateV2\x12\x35.tecton_proto.metadataservice.NewStateUpdateRequestV2\x1a\x36.tecton_proto.metadataservice.NewStateUpdateResponseV2\";\xa2\xbc\xe6\xc0\x05\x35\x1a\x15\x08\x01\x12\x11request.workspace*\x1ctecton/workspace#read_config\x12\xb8\x01\n\x10ValidateLocalFco\x12\x35.tecton_proto.metadataservice.ValidateLocalFcoRequest\x1a\x36.tecton_proto.metadataservice.ValidateLocalFcoResponse\"5\xa2\xbc\xe6\xc0\x05/*-tecton/organization#validate_notebook_objects\x12\xb6\x01\n\x10QueryStateUpdate\x12\x35.tecton_proto.metadataservice.QueryStateUpdateRequest\x1a\x36.tecton_proto.metadataservice.QueryStateUpdateResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xbc\x01\n\x12QueryStateUpdateV2\x12\x37.tecton_proto.metadataservice.QueryStateUpdateRequestV2\x1a\x38.tecton_proto.metadataservice.QueryStateUpdateResponseV2\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x8b\x01\n\x10\x41pplyStateUpdate\x12\x35.tecton_proto.metadataservice.ApplyStateUpdateRequest\x1a\x36.tecton_proto.metadataservice.ApplyStateUpdateResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb0\x01\n\nGetConfigs\x12\x16.google.protobuf.Empty\x1a\x30.tecton_proto.metadataservice.GetConfigsResponse\"X\x82\xd3\xe4\x93\x02%\" /v1/metadata-service/get-configs:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xcb\x01\n\x12GetGlobalsForWebUI\x12\x16.google.protobuf.Empty\x1a\x38.tecton_proto.metadataservice.GetGlobalsForWebUIResponse\"c\x82\xd3\xe4\x93\x02\x30\"+/v1/metadata-service/get-globals-for-web-ui:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\x98\x01\n\x0fGetLoginConfigs\x12\x16.google.protobuf.Empty\x1a\x30.tecton_proto.metadataservice.GetConfigsResponse\";\x82\xd3\xe4\x93\x02+\"&/v1/metadata-service/get-login-configs:\x01*\xa2\xbc\xe6\xc0\x05\x04\x08\x01\x10\x01\x12?\n\x03Nop\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x08\xa2\xbc\xe6\xc0\x05\x02\x10\x01\x12\xe3\x01\n\x19GetStateUpdatePlanSummary\x12>.tecton_proto.metadataservice.GetStateUpdatePlanSummaryRequest\x1a?.tecton_proto.metadataservice.GetStateUpdatePlanSummaryResponse\"E\x82\xd3\xe4\x93\x02\x37\"2/v1/metadata-service/get-state-update-plan-summary:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xed\x01\n\x11GetStateUpdateLog\x12\x36.tecton_proto.metadataservice.GetStateUpdateLogRequest\x1a\x37.tecton_proto.metadataservice.GetStateUpdateLogResponse\"g\x82\xd3\xe4\x93\x02.\")/v1/metadata-service/get-state-update-log:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xb0\x01\n\x0eGetRestoreInfo\x12\x33.tecton_proto.metadataservice.GetRestoreInfoRequest\x1a\x34.tecton_proto.metadataservice.GetRestoreInfoResponse\"3\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x8e\x02\n\x0f\x43reateWorkspace\x12\x34.tecton_proto.metadataservice.CreateWorkspaceRequest\x1a\x16.google.protobuf.Empty\"\xac\x01\xa2\xbc\xe6\xc0\x05v*$tecton/organization#create_workspace2N\n\x1b\x63\x61pabilities.materializable\x12\x04true\x1a)tecton/organization#create_workspace_live\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/create-workspace:\x01*\x12\x99\x01\n\x0f\x44\x65leteWorkspace\x12\x34.tecton_proto.metadataservice.DeleteWorkspaceRequest\x1a\x16.google.protobuf.Empty\"8\xa2\xbc\xe6\xc0\x05\x32\x1a\r\x08\x01\x12\tworkspace*!tecton/workspace#delete_workspace\x12\xb4\x01\n\x0eListWorkspaces\x12\x33.tecton_proto.metadataservice.ListWorkspacesRequest\x1a\x34.tecton_proto.metadataservice.ListWorkspacesResponse\"7\x82\xd3\xe4\x93\x02)\"$/v1/metadata-service/list-workspaces:\x01*\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xdf\x01\n\x0cGetWorkspace\x12\x31.tecton_proto.metadataservice.GetWorkspaceRequest\x1a\x32.tecton_proto.metadataservice.GetWorkspaceResponse\"h\x82\xd3\xe4\x93\x02\'\"\"/v1/metadata-service/get-workspace:\x01*\xa2\xbc\xe6\xc0\x05\x35\x1a\x12\x08\x01\x12\x0eworkspace_name*\x1ftecton/workspace#read_workspace\x12\xe5\x01\n\x10IntrospectApiKey\x12\x35.tecton_proto.metadataservice.IntrospectApiKeyRequest\x1a\x36.tecton_proto.metadataservice.IntrospectApiKeyResponse\"b\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-service/introspect-api-key:\x01*\xa2\xbc\xe6\xc0\x05**(tecton/organization#list_service_account\x12\xf7\x01\n\x14\x43reateServiceAccount\x12\x39.tecton_proto.metadataservice.CreateServiceAccountRequest\x1a:.tecton_proto.metadataservice.CreateServiceAccountResponse\"h\x82\xd3\xe4\x93\x02\x30\"+/v1/metadata-service/create-service-account:\x01*\xa2\xbc\xe6\xc0\x05,**tecton/organization#create_service_account\x12\xec\x01\n\x12GetServiceAccounts\x12\x37.tecton_proto.metadataservice.GetServiceAccountsRequest\x1a\x38.tecton_proto.metadataservice.GetServiceAccountsResponse\"c\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/get-service-account:\x01*\xa2\xbc\xe6\xc0\x05**(tecton/organization#list_service_account\x12\x82\x02\n\x14UpdateServiceAccount\x12\x39.tecton_proto.metadataservice.UpdateServiceAccountRequest\x1a:.tecton_proto.metadataservice.UpdateServiceAccountResponse\"s\x82\xd3\xe4\x93\x02\x30\"+/v1/metadata-service/update-service-account:\x01*\xa2\xbc\xe6\xc0\x05\x37\x1a\x06\x08\x02\x12\x02id*-tecton/service_account#manage_service_account\x12\x82\x02\n\x14\x44\x65leteServiceAccount\x12\x39.tecton_proto.metadataservice.DeleteServiceAccountRequest\x1a:.tecton_proto.metadataservice.DeleteServiceAccountResponse\"s\x82\xd3\xe4\x93\x02\x30\"+/v1/metadata-service/delete-service-account:\x01*\xa2\xbc\xe6\xc0\x05\x37\x1a\x06\x08\x02\x12\x02id*-tecton/service_account#manage_service_account\x12\xef\x01\n\x0c\x43reateApiKey\x12\x31.tecton_proto.metadataservice.CreateApiKeyRequest\x1a\x32.tecton_proto.metadataservice.CreateApiKeyResponse\"x\xa2\xbc\xe6\xc0\x05r**tecton/organization#create_service_account2B\n\x08is_admin\x12\x04true\x1a\x30tecton/organization#create_service_account_admin8\x01\x12\x9a\x01\n\x0c\x44\x65leteApiKey\x12\x31.tecton_proto.metadataservice.DeleteApiKeyRequest\x1a\x16.google.protobuf.Empty\"?\xa2\xbc\xe6\xc0\x05\x39\x1a\x06\x08\x02\x12\x02id*-tecton/service_account#manage_service_account8\x01\x12\xa4\x01\n\x0bListApiKeys\x12\x30.tecton_proto.metadataservice.ListApiKeysRequest\x1a\x31.tecton_proto.metadataservice.ListApiKeysResponse\"0\xa2\xbc\xe6\xc0\x05**(tecton/organization#list_service_account\x12\xda\x01\n\x1b\x43reateSavedFeatureDataFrame\x12@.tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest\x1a\x41.tecton_proto.metadataservice.CreateSavedFeatureDataFrameResponse\"6\xa2\xbc\xe6\xc0\x05\x30\x1a\r\x08\x01\x12\tworkspace*\x1ftecton/workspace#update_dataset\x12\xaf\x01\n\x1c\x41rchiveSavedFeatureDataFrame\x12\x41.tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameRequest\x1a\x42.tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xcf\x01\n\x18GetSavedFeatureDataFrame\x12=.tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest\x1a>.tecton_proto.metadataservice.GetSavedFeatureDataFrameResponse\"4\xa2\xbc\xe6\xc0\x05.\x1a\r\x08\x01\x12\tworkspace*\x1dtecton/workspace#read_dataset\x12\x9b\x02\n\x1cGetAllSavedFeatureDataFrames\x12\x41.tecton_proto.metadataservice.GetAllSavedFeatureDataFramesRequest\x1a\x42.tecton_proto.metadataservice.GetAllSavedFeatureDataFramesResponse\"t\x82\xd3\xe4\x93\x02:\"5/v1/metadata-service/get-all-saved-feature-dataframes:\x01*\xa2\xbc\xe6\xc0\x05.\x1a\r\x08\x01\x12\tworkspace*\x1dtecton/workspace#read_dataset\x12\xa6\x01\n\x19GetNewIngestDataframeInfo\x12>.tecton_proto.metadataservice.GetNewIngestDataframeInfoRequest\x1a?.tecton_proto.metadataservice.GetNewIngestDataframeInfoResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xb7\x01\n\x0fIngestDataframe\x12\x34.tecton_proto.metadataservice.IngestDataframeRequest\x1a\x35.tecton_proto.metadataservice.IngestDataframeResponse\"7\xa2\xbc\xe6\xc0\x05\x31\x1a\r\x08\x01\x12\tworkspace* tecton/workspace#ingest_features\x12\xcd\x01\n\x13GetClusterAdminInfo\x12\x16.google.protobuf.Empty\x1a\x39.tecton_proto.metadataservice.GetClusterAdminInfoResponse\"c\x82\xd3\xe4\x93\x02\x30\"+/v1/metadata-service/get-cluster-admin-info:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xe0\x01\n\x11\x43reateClusterUser\x12\x36.tecton_proto.metadataservice.CreateClusterUserRequest\x1a\x37.tecton_proto.metadataservice.CreateClusterUserResponse\"Z\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/create-cluster-user:\x01*\xa2\xbc\xe6\xc0\x05!*\x1ftecton/organization#create_user\x12\xe0\x01\n\x11\x44\x65leteClusterUser\x12\x36.tecton_proto.metadataservice.DeleteClusterUserRequest\x1a\x37.tecton_proto.metadataservice.DeleteClusterUserResponse\"Z\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/delete-cluster-user:\x01*\xa2\xbc\xe6\xc0\x05!*\x1ftecton/organization#manage_user\x12\xe0\x01\n\x11\x43lusterUserAction\x12\x36.tecton_proto.metadataservice.ClusterUserActionRequest\x1a\x37.tecton_proto.metadataservice.ClusterUserActionResponse\"Z\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/cluster-user-action:\x01*\xa2\xbc\xe6\xc0\x05!*\x1ftecton/organization#manage_user\x12\xdf\x01\n\x19GetUserDeploymentSettings\x12\x16.google.protobuf.Empty\x1a?.tecton_proto.metadataservice.GetUserDeploymentSettingsResponse\"i\x82\xd3\xe4\x93\x02\x36\"1/v1/metadata-service/get-user-deployment-settings:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\x9c\x02\n\x1cUpdateUserDeploymentSettings\x12\x41.tecton_proto.metadataservice.UpdateUserDeploymentSettingsRequest\x1a\x42.tecton_proto.metadataservice.UpdateUserDeploymentSettingsResponse\"u\x82\xd3\xe4\x93\x02\x39\"4/v1/metadata-service/update-user-deployment-settings:\x01*\xa2\xbc\xe6\xc0\x05\x30*.tecton/organization#manage_deployment_settings\x12\xec\x01\n\x1dGetInternalSparkClusterStatus\x12\x16.google.protobuf.Empty\x1a\x43.tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse\"n\x82\xd3\xe4\x93\x02;\"6/v1/metadata-service/get-internal-spark-cluster-status:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\x9a\x01\n\x15GetDeleteEntitiesInfo\x12:.tecton_proto.metadataservice.GetDeleteEntitiesInfoRequest\x1a;.tecton_proto.metadataservice.GetDeleteEntitiesInfoResponse\"\x08\xa2\xbc\xe6\xc0\x05\x02@\x01\x12\xc0\x01\n\x0e\x44\x65leteEntities\x12\x33.tecton_proto.metadataservice.DeleteEntitiesRequest\x1a\x34.tecton_proto.metadataservice.DeleteEntitiesResponse\"C\xa2\xbc\xe6\xc0\x05=\x1a\x19\x08\x01\x12\x15\x66\x63o_locator.workspace* tecton/workspace#delete_features\x12\xde\x01\n\x0fGetHiveMetadata\x12\x34.tecton_proto.metadataservice.GetHiveMetadataRequest\x1a\x35.tecton_proto.metadataservice.GetHiveMetadataResponse\"^\x82\xd3\xe4\x93\x02+\"&/v1/metadata-service/get-hive-metadata:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xde\x01\n\x0fGetFileMetadata\x12\x34.tecton_proto.metadataservice.GetFileMetadataRequest\x1a\x35.tecton_proto.metadataservice.GetFileMetadataResponse\"^\x82\xd3\xe4\x93\x02+\"&/v1/metadata-service/get-file-metadata:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xda\x01\n\x0cValidateFcos\x12\x31.tecton_proto.metadataservice.ValidateFcosRequest\x1a\x32.tecton_proto.metadataservice.ValidateFcosResponse\"c\x82\xd3\xe4\x93\x02\'\"\"/v1/metadata-service/validate-fcos:\x01*\xa2\xbc\xe6\xc0\x05\x30*.tecton/organization#manage_deployment_settings\x12\xf7\x01\n\x13GetOnboardingStatus\x12\x38.tecton_proto.metadataservice.GetOnboardingStatusRequest\x1a\x39.tecton_proto.metadataservice.GetOnboardingStatusResponse\"k\x82\xd3\xe4\x93\x02/\"*/v1/metadata-service/get-onboarding-status:\x01*\xa2\xbc\xe6\xc0\x05\x30\x1a\r\x08\x01\x12\tworkspace*\x1ftecton/workspace#read_workspace\x12\xcb\x01\n\x13SetOnboardingStatus\x12\x38.tecton_proto.metadataservice.SetOnboardingStatusRequest\x1a\x16.google.protobuf.Empty\"b\x82\xd3\xe4\x93\x02/\"*/v1/metadata-service/set-onboarding-status:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xe3\x01\n\x1aGetDataPlatformSetupStatus\x12\x16.google.protobuf.Empty\x1a@.tecton_proto.metadataservice.GetDataPlatformSetupStatusResponse\"k\x82\xd3\xe4\x93\x02\x38\"3/v1/metadata-service/get-data-platform-setup-status:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xe5\x01\n\x1bGetRetrieveFeaturesNotebook\x12\x16.google.protobuf.Empty\x1a\x41.tecton_proto.metadataservice.GetRetrieveFeaturesNotebookResponse\"k\x82\xd3\xe4\x93\x02\x38\"3/v1/metadata-service/get-retrieve-features-notebook:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\x80\x02\n\x16GetObservabilityConfig\x12;.tecton_proto.metadataservice.GetObservabilityConfigRequest\x1a<.tecton_proto.metadataservice.GetObservabilityConfigResponse\"k\x82\xd3\xe4\x93\x02\x32\"-/v1/metadata-service/get-observability-config:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\xd3\x01\n\x0bQueryMetric\x12\x30.tecton_proto.metadataservice.QueryMetricRequest\x1a\x31.tecton_proto.metadataservice.QueryMetricResponse\"_\x82\xd3\xe4\x93\x02&\"!/v1/metadata-service/query-metric:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x95\x02\n\x1bGetFeatureValidationHistory\x12@.tecton_proto.metadataservice.GetFeatureValidationHistoryRequest\x1a\x41.tecton_proto.metadataservice.GetFeatureValidationHistoryResponse\"q\x82\xd3\xe4\x93\x02\x38\"3/v1/metadata-service/get-feature-validation-history:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_config\x12\x95\x02\n\x1bGetFeatureValidationSummary\x12@.tecton_proto.metadataservice.GetFeatureValidationSummaryRequest\x1a\x41.tecton_proto.metadataservice.GetFeatureValidationSummaryResponse\"q\x82\xd3\xe4\x93\x02\x38\"3/v1/metadata-service/get-feature-validation-summary:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_metric\x12\x91\x02\n\x1aGetFeatureValidationResult\x12?.tecton_proto.metadataservice.GetFeatureValidationResultRequest\x1a@.tecton_proto.metadataservice.GetFeatureValidationResultResponse\"p\x82\xd3\xe4\x93\x02\x37\"2/v1/metadata-service/get-feature-validation-result:\x01*\xa2\xbc\xe6\xc0\x05-\x1a\r\x08\x01\x12\tworkspace*\x1ctecton/workspace#read_metric\x12\xfb\x01\n\x16GetFeatureServerConfig\x12;.tecton_proto.metadataservice.GetFeatureServerConfigRequest\x1a<.tecton_proto.metadataservice.GetFeatureServerConfigResponse\"f\x82\xd3\xe4\x93\x02\x33\"./v1/metadata-service/get-feature-server-config:\x01*\xa2\xbc\xe6\xc0\x05\'*%tecton/organization#read_organization\x12\xfe\x01\n\x16SetFeatureServerConfig\x12;.tecton_proto.metadataservice.SetFeatureServerConfigRequest\x1a<.tecton_proto.metadataservice.GetFeatureServerConfigResponse\"i\x82\xd3\xe4\x93\x02\x33\"./v1/metadata-service/set-feature-server-config:\x01*\xa2\xbc\xe6\xc0\x05**(tecton/organization#scale_feature_server\x12\xb5\x01\n\x07GetUser\x12,.tecton_proto.metadataservice.GetUserRequest\x1a-.tecton_proto.metadataservice.GetUserResponse\"M\x82\xd3\xe4\x93\x02\"\"\x1d/v1/metadata-service/get-user:\x01*\xa2\xbc\xe6\xc0\x05\x1f*\x1dtecton/organization#list_userBg\n\x1a\x63om.tecton.metadataserviceB\x14MetadataServiceProtoP\x01Z1github.com/tecton-ai/tecton_proto/metadataservice')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tecton_proto.metadataservice.metadata_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.tecton.metadataserviceB\024MetadataServiceProtoP\001Z1github.com/tecton-ai/tecton_proto/metadataservice'
  _APPLYSTATEUPDATEREQUEST.fields_by_name['applied_by']._options = None
  _APPLYSTATEUPDATEREQUEST.fields_by_name['applied_by']._serialized_options = b'\030\001'
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._options = None
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._serialized_options = b'8\001'
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._options = None
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._serialized_options = b'8\001'
  _METADATASERVICE.methods_by_name['GetFeatureService']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureService']._serialized_options = b'\202\323\344\223\002-\"(/v1/metadata-service/get-feature-service:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllFeatureServices']._options = None
  _METADATASERVICE.methods_by_name['GetAllFeatureServices']._serialized_options = b'\202\323\344\223\0022\"-/v1/metadata-service/get-all-feature-services:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureServiceSummary']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureServiceSummary']._serialized_options = b'\202\323\344\223\0025\"0/v1/metadata-service/get-feature-service-summary:\001*\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetServingStatus']._options = None
  _METADATASERVICE.methods_by_name['GetServingStatus']._serialized_options = b'\202\323\344\223\002,\"\'/v1/metadata-service/get-serving-status:\001*\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetFVServingStatusForFS']._options = None
  _METADATASERVICE.methods_by_name['GetFVServingStatusForFS']._serialized_options = b'\202\323\344\223\0026\"1/v1/metadata-service/get-fv-serving-status-for-fs:\001*\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetAllFeatureFreshness']._options = None
  _METADATASERVICE.methods_by_name['GetAllFeatureFreshness']._serialized_options = b'\202\323\344\223\0023\"./v1/metadata-service/get-all-feature-freshness:\001*\242\274\346\300\005<\032\r\010\001\022\tworkspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetFeatureFreshness']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureFreshness']._serialized_options = b'\202\323\344\223\002/\"*/v1/metadata-service/get-feature-freshness:\001*\242\274\346\300\005H\032\031\010\001\022\025fco_locator.workspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetMaterializationStatus']._options = None
  _METADATASERVICE.methods_by_name['GetMaterializationStatus']._serialized_options = b'\202\323\344\223\0024\"//v1/metadata-service/get-materialization-status:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetAllMaterializationStatusInLiveWorkspaces']._options = None
  _METADATASERVICE.methods_by_name['GetAllMaterializationStatusInLiveWorkspaces']._serialized_options = b'\202\323\344\223\002J\"E/v1/metadata-service/get-all-materialization-status-in-live-workspace:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetJobs']._options = None
  _METADATASERVICE.methods_by_name['GetJobs']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/metadata-service/jobs:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['ForceRetryMaterializationTask']._options = None
  _METADATASERVICE.methods_by_name['ForceRetryMaterializationTask']._serialized_options = b'\202\323\344\223\002:\"5/v1/metadata-service/force-retry-materialization-task:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetSparkConfig']._options = None
  _METADATASERVICE.methods_by_name['GetSparkConfig']._serialized_options = b'\202\323\344\223\002*\"%/v1/metadata-service/get-spark-config:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetMetricAndExpectationDefinition']._options = None
  _METADATASERVICE.methods_by_name['GetMetricAndExpectationDefinition']._serialized_options = b'\202\323\344\223\002?\":/v1/metadata-service/get-metric-and-expectation-definition:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureView']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureView']._serialized_options = b'\202\323\344\223\002*\"%/v1/metadata-service/get-feature-view:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetMaterializingFeatureViewsInLiveWorkspaces']._options = None
  _METADATASERVICE.methods_by_name['GetMaterializingFeatureViewsInLiveWorkspaces']._serialized_options = b'\202\323\344\223\002F\"A/v1/metadata-service/get-materializing-features-in-live-workspace:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['QueryFeatureViews']._options = None
  _METADATASERVICE.methods_by_name['QueryFeatureViews']._serialized_options = b'\202\323\344\223\002-\"(/v1/metadata-service/query-feature-views:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureViewSummary']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureViewSummary']._serialized_options = b'\202\323\344\223\0022\"-/v1/metadata-package/get-feature-view-summary:\001*\242\274\346\300\005H\032\031\010\001\022\025fco_locator.workspace*+tecton/workspace#read_materialization_state'
  _METADATASERVICE.methods_by_name['GetFeatureConsumption']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureConsumption']._serialized_options = b'\202\323\344\223\0026\"1/v1/metadata-service/get-feature-view-consumption:\001*\242\274\346\300\0059\032\031\010\001\022\025fco_locator.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetVirtualDataSource']._options = None
  _METADATASERVICE.methods_by_name['GetVirtualDataSource']._serialized_options = b'\202\323\344\223\0021\",/v1/metadata-service/get-virtual-data-source:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllVirtualDataSources']._options = None
  _METADATASERVICE.methods_by_name['GetAllVirtualDataSources']._serialized_options = b'\202\323\344\223\0026\"1/v1/metadata-service/get-all-virtual-data-sources:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['IngestClientLogs']._options = None
  _METADATASERVICE.methods_by_name['IngestClientLogs']._serialized_options = b'\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['IngestAnalytics']._options = None
  _METADATASERVICE.methods_by_name['IngestAnalytics']._serialized_options = b'\202\323\344\223\002*\"%/v1/metadata-service/ingest-analytics:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetVirtualDataSourceSummary']._options = None
  _METADATASERVICE.methods_by_name['GetVirtualDataSourceSummary']._serialized_options = b'\202\323\344\223\0029\"4/v1/metadata-service/get-virtual-data-source-summary:\001*\242\274\346\300\0059\032\031\010\001\022\025fco_locator.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFcos']._options = None
  _METADATASERVICE.methods_by_name['GetFcos']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/metadata-service/get-fcos:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetEntity']._options = None
  _METADATASERVICE.methods_by_name['GetEntity']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllEntities']._options = None
  _METADATASERVICE.methods_by_name['GetAllEntities']._serialized_options = b'\202\323\344\223\002*\"%/v1/metadata-service/get-all-entities:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetEntitySummary']._options = None
  _METADATASERVICE.methods_by_name['GetEntitySummary']._serialized_options = b'\202\323\344\223\002,\"\'/v1/metadata-package/get-entity-summary:\001*\242\274\346\300\0059\032\031\010\001\022\025fco_locator.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetTransformation']._options = None
  _METADATASERVICE.methods_by_name['GetTransformation']._serialized_options = b'\202\323\344\223\002,\"\'/v1/metadata-service/get-transformation:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetAllTransformations']._options = None
  _METADATASERVICE.methods_by_name['GetAllTransformations']._serialized_options = b'\202\323\344\223\0021\",/v1/metadata-service/get-all-transformations:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetTransformationSummary']._options = None
  _METADATASERVICE.methods_by_name['GetTransformationSummary']._serialized_options = b'\202\323\344\223\0024\"//v1/metadata-package/get-transformation-summary:\001*\242\274\346\300\0059\032\031\010\001\022\025fco_locator.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['FindFcoWorkspace']._options = None
  _METADATASERVICE.methods_by_name['FindFcoWorkspace']._serialized_options = b'\202\323\344\223\002,\"\'/v1/metadata-service/find-fco-workspace:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['NewStateUpdate']._options = None
  _METADATASERVICE.methods_by_name['NewStateUpdate']._serialized_options = b'\242\274\346\300\0055\032\025\010\001\022\021request.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['NewStateUpdateV2']._options = None
  _METADATASERVICE.methods_by_name['NewStateUpdateV2']._serialized_options = b'\242\274\346\300\0055\032\025\010\001\022\021request.workspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['ValidateLocalFco']._options = None
  _METADATASERVICE.methods_by_name['ValidateLocalFco']._serialized_options = b'\242\274\346\300\005/*-tecton/organization#validate_notebook_objects'
  _METADATASERVICE.methods_by_name['QueryStateUpdate']._options = None
  _METADATASERVICE.methods_by_name['QueryStateUpdate']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['QueryStateUpdateV2']._options = None
  _METADATASERVICE.methods_by_name['QueryStateUpdateV2']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['ApplyStateUpdate']._options = None
  _METADATASERVICE.methods_by_name['ApplyStateUpdate']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetConfigs']._options = None
  _METADATASERVICE.methods_by_name['GetConfigs']._serialized_options = b'\202\323\344\223\002%\" /v1/metadata-service/get-configs:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetGlobalsForWebUI']._options = None
  _METADATASERVICE.methods_by_name['GetGlobalsForWebUI']._serialized_options = b'\202\323\344\223\0020\"+/v1/metadata-service/get-globals-for-web-ui:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetLoginConfigs']._options = None
  _METADATASERVICE.methods_by_name['GetLoginConfigs']._serialized_options = b'\202\323\344\223\002+\"&/v1/metadata-service/get-login-configs:\001*\242\274\346\300\005\004\010\001\020\001'
  _METADATASERVICE.methods_by_name['Nop']._options = None
  _METADATASERVICE.methods_by_name['Nop']._serialized_options = b'\242\274\346\300\005\002\020\001'
  _METADATASERVICE.methods_by_name['GetStateUpdatePlanSummary']._options = None
  _METADATASERVICE.methods_by_name['GetStateUpdatePlanSummary']._serialized_options = b'\202\323\344\223\0027\"2/v1/metadata-service/get-state-update-plan-summary:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetStateUpdateLog']._options = None
  _METADATASERVICE.methods_by_name['GetStateUpdateLog']._serialized_options = b'\202\323\344\223\002.\")/v1/metadata-service/get-state-update-log:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetRestoreInfo']._options = None
  _METADATASERVICE.methods_by_name['GetRestoreInfo']._serialized_options = b'\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['CreateWorkspace']._options = None
  _METADATASERVICE.methods_by_name['CreateWorkspace']._serialized_options = b'\242\274\346\300\005v*$tecton/organization#create_workspace2N\n\033capabilities.materializable\022\004true\032)tecton/organization#create_workspace_live\202\323\344\223\002*\"%/v1/metadata-service/create-workspace:\001*'
  _METADATASERVICE.methods_by_name['DeleteWorkspace']._options = None
  _METADATASERVICE.methods_by_name['DeleteWorkspace']._serialized_options = b'\242\274\346\300\0052\032\r\010\001\022\tworkspace*!tecton/workspace#delete_workspace'
  _METADATASERVICE.methods_by_name['ListWorkspaces']._options = None
  _METADATASERVICE.methods_by_name['ListWorkspaces']._serialized_options = b'\202\323\344\223\002)\"$/v1/metadata-service/list-workspaces:\001*\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetWorkspace']._options = None
  _METADATASERVICE.methods_by_name['GetWorkspace']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/metadata-service/get-workspace:\001*\242\274\346\300\0055\032\022\010\001\022\016workspace_name*\037tecton/workspace#read_workspace'
  _METADATASERVICE.methods_by_name['IntrospectApiKey']._options = None
  _METADATASERVICE.methods_by_name['IntrospectApiKey']._serialized_options = b'\202\323\344\223\002,\"\'/v1/metadata-service/introspect-api-key:\001*\242\274\346\300\005**(tecton/organization#list_service_account'
  _METADATASERVICE.methods_by_name['CreateServiceAccount']._options = None
  _METADATASERVICE.methods_by_name['CreateServiceAccount']._serialized_options = b'\202\323\344\223\0020\"+/v1/metadata-service/create-service-account:\001*\242\274\346\300\005,**tecton/organization#create_service_account'
  _METADATASERVICE.methods_by_name['GetServiceAccounts']._options = None
  _METADATASERVICE.methods_by_name['GetServiceAccounts']._serialized_options = b'\202\323\344\223\002-\"(/v1/metadata-service/get-service-account:\001*\242\274\346\300\005**(tecton/organization#list_service_account'
  _METADATASERVICE.methods_by_name['UpdateServiceAccount']._options = None
  _METADATASERVICE.methods_by_name['UpdateServiceAccount']._serialized_options = b'\202\323\344\223\0020\"+/v1/metadata-service/update-service-account:\001*\242\274\346\300\0057\032\006\010\002\022\002id*-tecton/service_account#manage_service_account'
  _METADATASERVICE.methods_by_name['DeleteServiceAccount']._options = None
  _METADATASERVICE.methods_by_name['DeleteServiceAccount']._serialized_options = b'\202\323\344\223\0020\"+/v1/metadata-service/delete-service-account:\001*\242\274\346\300\0057\032\006\010\002\022\002id*-tecton/service_account#manage_service_account'
  _METADATASERVICE.methods_by_name['CreateApiKey']._options = None
  _METADATASERVICE.methods_by_name['CreateApiKey']._serialized_options = b'\242\274\346\300\005r**tecton/organization#create_service_account2B\n\010is_admin\022\004true\0320tecton/organization#create_service_account_admin8\001'
  _METADATASERVICE.methods_by_name['DeleteApiKey']._options = None
  _METADATASERVICE.methods_by_name['DeleteApiKey']._serialized_options = b'\242\274\346\300\0059\032\006\010\002\022\002id*-tecton/service_account#manage_service_account8\001'
  _METADATASERVICE.methods_by_name['ListApiKeys']._options = None
  _METADATASERVICE.methods_by_name['ListApiKeys']._serialized_options = b'\242\274\346\300\005**(tecton/organization#list_service_account'
  _METADATASERVICE.methods_by_name['CreateSavedFeatureDataFrame']._options = None
  _METADATASERVICE.methods_by_name['CreateSavedFeatureDataFrame']._serialized_options = b'\242\274\346\300\0050\032\r\010\001\022\tworkspace*\037tecton/workspace#update_dataset'
  _METADATASERVICE.methods_by_name['ArchiveSavedFeatureDataFrame']._options = None
  _METADATASERVICE.methods_by_name['ArchiveSavedFeatureDataFrame']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['GetSavedFeatureDataFrame']._options = None
  _METADATASERVICE.methods_by_name['GetSavedFeatureDataFrame']._serialized_options = b'\242\274\346\300\005.\032\r\010\001\022\tworkspace*\035tecton/workspace#read_dataset'
  _METADATASERVICE.methods_by_name['GetAllSavedFeatureDataFrames']._options = None
  _METADATASERVICE.methods_by_name['GetAllSavedFeatureDataFrames']._serialized_options = b'\202\323\344\223\002:\"5/v1/metadata-service/get-all-saved-feature-dataframes:\001*\242\274\346\300\005.\032\r\010\001\022\tworkspace*\035tecton/workspace#read_dataset'
  _METADATASERVICE.methods_by_name['GetNewIngestDataframeInfo']._options = None
  _METADATASERVICE.methods_by_name['GetNewIngestDataframeInfo']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['IngestDataframe']._options = None
  _METADATASERVICE.methods_by_name['IngestDataframe']._serialized_options = b'\242\274\346\300\0051\032\r\010\001\022\tworkspace* tecton/workspace#ingest_features'
  _METADATASERVICE.methods_by_name['GetClusterAdminInfo']._options = None
  _METADATASERVICE.methods_by_name['GetClusterAdminInfo']._serialized_options = b'\202\323\344\223\0020\"+/v1/metadata-service/get-cluster-admin-info:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['CreateClusterUser']._options = None
  _METADATASERVICE.methods_by_name['CreateClusterUser']._serialized_options = b'\202\323\344\223\002-\"(/v1/metadata-service/create-cluster-user:\001*\242\274\346\300\005!*\037tecton/organization#create_user'
  _METADATASERVICE.methods_by_name['DeleteClusterUser']._options = None
  _METADATASERVICE.methods_by_name['DeleteClusterUser']._serialized_options = b'\202\323\344\223\002-\"(/v1/metadata-service/delete-cluster-user:\001*\242\274\346\300\005!*\037tecton/organization#manage_user'
  _METADATASERVICE.methods_by_name['ClusterUserAction']._options = None
  _METADATASERVICE.methods_by_name['ClusterUserAction']._serialized_options = b'\202\323\344\223\002-\"(/v1/metadata-service/cluster-user-action:\001*\242\274\346\300\005!*\037tecton/organization#manage_user'
  _METADATASERVICE.methods_by_name['GetUserDeploymentSettings']._options = None
  _METADATASERVICE.methods_by_name['GetUserDeploymentSettings']._serialized_options = b'\202\323\344\223\0026\"1/v1/metadata-service/get-user-deployment-settings:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['UpdateUserDeploymentSettings']._options = None
  _METADATASERVICE.methods_by_name['UpdateUserDeploymentSettings']._serialized_options = b'\202\323\344\223\0029\"4/v1/metadata-service/update-user-deployment-settings:\001*\242\274\346\300\0050*.tecton/organization#manage_deployment_settings'
  _METADATASERVICE.methods_by_name['GetInternalSparkClusterStatus']._options = None
  _METADATASERVICE.methods_by_name['GetInternalSparkClusterStatus']._serialized_options = b'\202\323\344\223\002;\"6/v1/metadata-service/get-internal-spark-cluster-status:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetDeleteEntitiesInfo']._options = None
  _METADATASERVICE.methods_by_name['GetDeleteEntitiesInfo']._serialized_options = b'\242\274\346\300\005\002@\001'
  _METADATASERVICE.methods_by_name['DeleteEntities']._options = None
  _METADATASERVICE.methods_by_name['DeleteEntities']._serialized_options = b'\242\274\346\300\005=\032\031\010\001\022\025fco_locator.workspace* tecton/workspace#delete_features'
  _METADATASERVICE.methods_by_name['GetHiveMetadata']._options = None
  _METADATASERVICE.methods_by_name['GetHiveMetadata']._serialized_options = b'\202\323\344\223\002+\"&/v1/metadata-service/get-hive-metadata:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetFileMetadata']._options = None
  _METADATASERVICE.methods_by_name['GetFileMetadata']._serialized_options = b'\202\323\344\223\002+\"&/v1/metadata-service/get-file-metadata:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['ValidateFcos']._options = None
  _METADATASERVICE.methods_by_name['ValidateFcos']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/metadata-service/validate-fcos:\001*\242\274\346\300\0050*.tecton/organization#manage_deployment_settings'
  _METADATASERVICE.methods_by_name['GetOnboardingStatus']._options = None
  _METADATASERVICE.methods_by_name['GetOnboardingStatus']._serialized_options = b'\202\323\344\223\002/\"*/v1/metadata-service/get-onboarding-status:\001*\242\274\346\300\0050\032\r\010\001\022\tworkspace*\037tecton/workspace#read_workspace'
  _METADATASERVICE.methods_by_name['SetOnboardingStatus']._options = None
  _METADATASERVICE.methods_by_name['SetOnboardingStatus']._serialized_options = b'\202\323\344\223\002/\"*/v1/metadata-service/set-onboarding-status:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetDataPlatformSetupStatus']._options = None
  _METADATASERVICE.methods_by_name['GetDataPlatformSetupStatus']._serialized_options = b'\202\323\344\223\0028\"3/v1/metadata-service/get-data-platform-setup-status:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetRetrieveFeaturesNotebook']._options = None
  _METADATASERVICE.methods_by_name['GetRetrieveFeaturesNotebook']._serialized_options = b'\202\323\344\223\0028\"3/v1/metadata-service/get-retrieve-features-notebook:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['GetObservabilityConfig']._options = None
  _METADATASERVICE.methods_by_name['GetObservabilityConfig']._serialized_options = b'\202\323\344\223\0022\"-/v1/metadata-service/get-observability-config:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['QueryMetric']._options = None
  _METADATASERVICE.methods_by_name['QueryMetric']._serialized_options = b'\202\323\344\223\002&\"!/v1/metadata-service/query-metric:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureValidationHistory']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureValidationHistory']._serialized_options = b'\202\323\344\223\0028\"3/v1/metadata-service/get-feature-validation-history:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_config'
  _METADATASERVICE.methods_by_name['GetFeatureValidationSummary']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureValidationSummary']._serialized_options = b'\202\323\344\223\0028\"3/v1/metadata-service/get-feature-validation-summary:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_metric'
  _METADATASERVICE.methods_by_name['GetFeatureValidationResult']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureValidationResult']._serialized_options = b'\202\323\344\223\0027\"2/v1/metadata-service/get-feature-validation-result:\001*\242\274\346\300\005-\032\r\010\001\022\tworkspace*\034tecton/workspace#read_metric'
  _METADATASERVICE.methods_by_name['GetFeatureServerConfig']._options = None
  _METADATASERVICE.methods_by_name['GetFeatureServerConfig']._serialized_options = b'\202\323\344\223\0023\"./v1/metadata-service/get-feature-server-config:\001*\242\274\346\300\005\'*%tecton/organization#read_organization'
  _METADATASERVICE.methods_by_name['SetFeatureServerConfig']._options = None
  _METADATASERVICE.methods_by_name['SetFeatureServerConfig']._serialized_options = b'\202\323\344\223\0023\"./v1/metadata-service/set-feature-server-config:\001*\242\274\346\300\005**(tecton/organization#scale_feature_server'
  _METADATASERVICE.methods_by_name['GetUser']._options = None
  _METADATASERVICE.methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/metadata-service/get-user:\001*\242\274\346\300\005\037*\035tecton/organization#list_user'
  _SORTDIRECTION._serialized_start=24875
  _SORTDIRECTION._serialized_end=24937
  _JOBSKEYSET._serialized_start=1685
  _JOBSKEYSET._serialized_end=1797
  _PAGINATIONREQUEST._serialized_start=1800
  _PAGINATIONREQUEST._serialized_end=2008
  _PAGINATIONRESPONSE._serialized_start=2011
  _PAGINATIONRESPONSE._serialized_end=2251
  _GETFEATURESERVICEREQUEST._serialized_start=2254
  _GETFEATURESERVICEREQUEST._serialized_end=2408
  _GETFEATURESERVICERESPONSE._serialized_start=2410
  _GETFEATURESERVICERESPONSE._serialized_end=2507
  _GETALLFEATURESERVICESREQUEST._serialized_start=2509
  _GETALLFEATURESERVICESREQUEST._serialized_end=2569
  _GETALLFEATURESERVICESRESPONSE._serialized_start=2571
  _GETALLFEATURESERVICESRESPONSE._serialized_end=2680
  _GETFEATURESERVICESUMMARYREQUEST._serialized_start=2683
  _GETFEATURESERVICESUMMARYREQUEST._serialized_end=2882
  _GETFEATURESERVICESUMMARYRESPONSE._serialized_start=2885
  _GETFEATURESERVICESUMMARYRESPONSE._serialized_end=3025
  _GETVIRTUALDATASOURCESUMMARYREQUEST._serialized_start=3027
  _GETVIRTUALDATASOURCESUMMARYREQUEST._serialized_end=3129
  _GETVIRTUALDATASOURCESUMMARYRESPONSE._serialized_start=3131
  _GETVIRTUALDATASOURCESUMMARYRESPONSE._serialized_end=3232
  _GETTRANSFORMATIONSUMMARYREQUEST._serialized_start=3234
  _GETTRANSFORMATIONSUMMARYREQUEST._serialized_end=3333
  _GETTRANSFORMATIONSUMMARYRESPONSE._serialized_start=3335
  _GETTRANSFORMATIONSUMMARYRESPONSE._serialized_end=3433
  _GETENTITYSUMMARYREQUEST._serialized_start=3435
  _GETENTITYSUMMARYREQUEST._serialized_end=3526
  _GETENTITYSUMMARYRESPONSE._serialized_start=3528
  _GETENTITYSUMMARYRESPONSE._serialized_end=3618
  _GETSERVINGSTATUSREQUEST._serialized_start=3621
  _GETSERVINGSTATUSREQUEST._serialized_end=3838
  _GETFVSERVINGSTATUSFORFSREQUEST._serialized_start=3841
  _GETFVSERVINGSTATUSFORFSREQUEST._serialized_end=4055
  _GETFVSERVINGSTATUSFORFSRESPONSE._serialized_start=4058
  _GETFVSERVINGSTATUSFORFSRESPONSE._serialized_end=4289
  _GETSERVINGSTATUSRESPONSE._serialized_start=4291
  _GETSERVINGSTATUSRESPONSE._serialized_end=4412
  _GETALLFEATUREFRESHNESSREQUEST._serialized_start=4414
  _GETALLFEATUREFRESHNESSREQUEST._serialized_end=4475
  _GETALLFEATUREFRESHNESSRESPONSE._serialized_start=4477
  _GETALLFEATUREFRESHNESSRESPONSE._serialized_end=4592
  _GETFEATUREFRESHNESSREQUEST._serialized_start=4594
  _GETFEATUREFRESHNESSREQUEST._serialized_end=4688
  _GETFEATUREFRESHNESSRESPONSE._serialized_start=4690
  _GETFEATUREFRESHNESSRESPONSE._serialized_end=4798
  _GETFEATURECONSUMPTIONREQUEST._serialized_start=4800
  _GETFEATURECONSUMPTIONREQUEST._serialized_end=4896
  _GETFEATURECONSUMPTIONRESPONSE._serialized_start=4898
  _GETFEATURECONSUMPTIONRESPONSE._serialized_end=5015
  _GETMATERIALIZATIONSTATUSREQUEST._serialized_start=5017
  _GETMATERIALIZATIONSTATUSREQUEST._serialized_end=5121
  _GETMATERIALIZATIONSTATUSRESPONSE._serialized_start=5124
  _GETMATERIALIZATIONSTATUSRESPONSE._serialized_end=5255
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST._serialized_start=5257
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST._serialized_end=5343
  _COUNTRANGE._serialized_start=5345
  _COUNTRANGE._serialized_end=5397
  _DURATIONRANGE._serialized_start=5399
  _DURATIONRANGE._serialized_end=5508
  _DATETIMERANGE._serialized_start=5510
  _DATETIMERANGE._serialized_end=5621
  _GETJOBSREQUEST._serialized_start=5624
  _GETJOBSREQUEST._serialized_end=6394
  _FEATUREVIEWMATERIALIZATIONSTATUS._serialized_start=6397
  _FEATUREVIEWMATERIALIZATIONSTATUS._serialized_end=6594
  _TASKWITHATTEMPTS._serialized_start=6597
  _TASKWITHATTEMPTS._serialized_end=7162
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE._serialized_start=7165
  _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE._serialized_end=7362
  _GETJOBSRESPONSE._serialized_start=7365
  _GETJOBSRESPONSE._serialized_end=7558
  _FORCERETRYMATERIALIZATIONTASKREQUEST._serialized_start=7561
  _FORCERETRYMATERIALIZATIONTASKREQUEST._serialized_end=7721
  _FORCERETRYMATERIALIZATIONTASKRESPONSE._serialized_start=7723
  _FORCERETRYMATERIALIZATIONTASKRESPONSE._serialized_end=7799
  _GETFCOSREQUEST._serialized_start=7801
  _GETFCOSREQUEST._serialized_end=7847
  _GETFCOSRESPONSE._serialized_start=7849
  _GETFCOSRESPONSE._serialized_end=7936
  _GETSPARKCONFIGREQUEST._serialized_start=7938
  _GETSPARKCONFIGREQUEST._serialized_end=8035
  _GETSPARKCONFIGRESPONSE._serialized_start=8038
  _GETSPARKCONFIGRESPONSE._serialized_end=8214
  _GETMETRICANDEXPECTATIONDEFINITIONREQUEST._serialized_start=8216
  _GETMETRICANDEXPECTATIONDEFINITIONREQUEST._serialized_end=8332
  _GETMETRICANDEXPECTATIONDEFINITIONRESPONSE._serialized_start=8335
  _GETMETRICANDEXPECTATIONDEFINITIONRESPONSE._serialized_end=8691
  _GETFEATUREVIEWREQUEST._serialized_start=8694
  _GETFEATUREVIEWREQUEST._serialized_end=8839
  _GETFEATUREVIEWRESPONSE._serialized_start=8841
  _GETFEATUREVIEWRESPONSE._serialized_end=8935
  _GETFEATUREVIEWSUMMARYREQUEST._serialized_start=8937
  _GETFEATUREVIEWSUMMARYREQUEST._serialized_end=9033
  _GETFEATUREVIEWSUMMARYRESPONSE._serialized_start=9035
  _GETFEATUREVIEWSUMMARYRESPONSE._serialized_end=9130
  _QUERYFEATUREVIEWSREQUEST._serialized_start=9132
  _QUERYFEATUREVIEWSREQUEST._serialized_end=9214
  _QUERYFEATUREVIEWSRESPONSE._serialized_start=9216
  _QUERYFEATUREVIEWSRESPONSE._serialized_end=9313
  _GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE._serialized_start=9315
  _GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE._serialized_end=9438
  _GETVIRTUALDATASOURCEREQUEST._serialized_start=9441
  _GETVIRTUALDATASOURCEREQUEST._serialized_end=9627
  _GETVIRTUALDATASOURCERESPONSE._serialized_start=9629
  _GETVIRTUALDATASOURCERESPONSE._serialized_end=9729
  _GETALLVIRTUALDATASOURCESREQUEST._serialized_start=9731
  _GETALLVIRTUALDATASOURCESREQUEST._serialized_end=9794
  _GETALLVIRTUALDATASOURCESRESPONSE._serialized_start=9796
  _GETALLVIRTUALDATASOURCESRESPONSE._serialized_end=9918
  _GETENTITYREQUEST._serialized_start=9921
  _GETENTITYREQUEST._serialized_end=10072
  _GETENTITYRESPONSE._serialized_start=10074
  _GETENTITYRESPONSE._serialized_end=10163
  _GETALLENTITIESREQUEST._serialized_start=10165
  _GETALLENTITIESREQUEST._serialized_end=10218
  _GETALLENTITIESRESPONSE._serialized_start=10220
  _GETALLENTITIESRESPONSE._serialized_end=10299
  _GETTRANSFORMATIONREQUEST._serialized_start=10302
  _GETTRANSFORMATIONREQUEST._serialized_end=10477
  _GETTRANSFORMATIONRESPONSE._serialized_start=10479
  _GETTRANSFORMATIONRESPONSE._serialized_end=10582
  _GETALLTRANSFORMATIONSREQUEST._serialized_start=10584
  _GETALLTRANSFORMATIONSREQUEST._serialized_end=10644
  _GETALLTRANSFORMATIONSRESPONSE._serialized_start=10646
  _GETALLTRANSFORMATIONSRESPONSE._serialized_end=10760
  _FINDFCOWORKSPACEREQUEST._serialized_start=10762
  _FINDFCOWORKSPACEREQUEST._serialized_end=10828
  _FINDFCOWORKSPACERESPONSE._serialized_start=10830
  _FINDFCOWORKSPACERESPONSE._serialized_end=10886
  _INGESTCLIENTLOGSREQUEST._serialized_start=10888
  _INGESTCLIENTLOGSREQUEST._serialized_end=11010
  _INGESTANALYTICSREQUEST._serialized_start=11012
  _INGESTANALYTICSREQUEST._serialized_end=11130
  _NEWSTATEUPDATEREQUEST._serialized_start=11133
  _NEWSTATEUPDATEREQUEST._serialized_end=11324
  _NEWSTATEUPDATEREQUESTV2._serialized_start=11327
  _NEWSTATEUPDATEREQUESTV2._serialized_end=11580
  _NEWSTATEUPDATERESPONSE._serialized_start=11583
  _NEWSTATEUPDATERESPONSE._serialized_end=11814
  _NEWSTATEUPDATERESPONSEV2._serialized_start=11817
  _NEWSTATEUPDATERESPONSEV2._serialized_end=12052
  _QUERYSTATEUPDATEREQUEST._serialized_start=12054
  _QUERYSTATEUPDATEREQUEST._serialized_end=12161
  _QUERYSTATEUPDATEREQUESTV2._serialized_start=12164
  _QUERYSTATEUPDATEREQUESTV2._serialized_end=12333
  _QUERYSTATEUPDATERESPONSE._serialized_start=12336
  _QUERYSTATEUPDATERESPONSE._serialized_end=12676
  _QUERYSTATEUPDATERESPONSEV2._serialized_start=12679
  _QUERYSTATEUPDATERESPONSEV2._serialized_end=13040
  _GETSTATEUPDATEPLANSUMMARYREQUEST._serialized_start=13042
  _GETSTATEUPDATEPLANSUMMARYREQUEST._serialized_end=13126
  _GETSTATEUPDATEPLANSUMMARYRESPONSE._serialized_start=13128
  _GETSTATEUPDATEPLANSUMMARYRESPONSE._serialized_end=13226
  _APPLYSTATEUPDATEREQUEST._serialized_start=13228
  _APPLYSTATEUPDATEREQUEST._serialized_end=13340
  _APPLYSTATEUPDATERESPONSE._serialized_start=13342
  _APPLYSTATEUPDATERESPONSE._serialized_end=13368
  _GETCONFIGSRESPONSE._serialized_start=13371
  _GETCONFIGSRESPONSE._serialized_end=13549
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._serialized_start=13489
  _GETCONFIGSRESPONSE_KEYVALUESENTRY._serialized_end=13549
  _GETGLOBALSFORWEBUIRESPONSE._serialized_start=13552
  _GETGLOBALSFORWEBUIRESPONSE._serialized_end=13746
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._serialized_start=13489
  _GETGLOBALSFORWEBUIRESPONSE_KEYVALUESENTRY._serialized_end=13549
  _GETSTATEUPDATELOGREQUEST._serialized_start=13748
  _GETSTATEUPDATELOGREQUEST._serialized_end=13826
  _GETSTATEUPDATELOGRESPONSE._serialized_start=13828
  _GETSTATEUPDATELOGRESPONSE._serialized_end=13918
  _GETRESTOREINFOREQUEST._serialized_start=13920
  _GETRESTOREINFOREQUEST._serialized_end=14002
  _GETRESTOREINFORESPONSE._serialized_start=14005
  _GETRESTOREINFORESPONSE._serialized_end=14155
  _CREATEWORKSPACEREQUEST._serialized_start=14158
  _CREATEWORKSPACEREQUEST._serialized_end=14305
  _DELETEWORKSPACEREQUEST._serialized_start=14307
  _DELETEWORKSPACEREQUEST._serialized_end=14361
  _INTROSPECTAPIKEYREQUEST._serialized_start=14363
  _INTROSPECTAPIKEYREQUEST._serialized_end=14413
  _INTROSPECTAPIKEYRESPONSE._serialized_start=14416
  _INTROSPECTAPIKEYRESPONSE._serialized_end=14619
  _CREATEAPIKEYREQUEST._serialized_start=14621
  _CREATEAPIKEYREQUEST._serialized_end=14703
  _CREATEAPIKEYRESPONSE._serialized_start=14705
  _CREATEAPIKEYRESPONSE._serialized_end=14786
  _DELETEAPIKEYREQUEST._serialized_start=14788
  _DELETEAPIKEYREQUEST._serialized_end=14850
  _LISTAPIKEYSREQUEST._serialized_start=14852
  _LISTAPIKEYSREQUEST._serialized_end=14915
  _LISTAPIKEYSRESPONSE._serialized_start=14917
  _LISTAPIKEYSRESPONSE._serialized_end=14998
  _SERVICEACCOUNT._serialized_start=15001
  _SERVICEACCOUNT._serialized_end=15229
  _CREATESERVICEACCOUNTREQUEST._serialized_start=15231
  _CREATESERVICEACCOUNTREQUEST._serialized_end=15314
  _CREATESERVICEACCOUNTRESPONSE._serialized_start=15317
  _CREATESERVICEACCOUNTRESPONSE._serialized_end=15471
  _GETSERVICEACCOUNTSREQUEST._serialized_start=15473
  _GETSERVICEACCOUNTSREQUEST._serialized_end=15542
  _GETSERVICEACCOUNTSRESPONSE._serialized_start=15544
  _GETSERVICEACCOUNTSRESPONSE._serialized_end=15661
  _UPDATESERVICEACCOUNTREQUEST._serialized_start=15664
  _UPDATESERVICEACCOUNTREQUEST._serialized_end=15792
  _UPDATESERVICEACCOUNTRESPONSE._serialized_start=15795
  _UPDATESERVICEACCOUNTRESPONSE._serialized_end=15924
  _DELETESERVICEACCOUNTREQUEST._serialized_start=15926
  _DELETESERVICEACCOUNTREQUEST._serialized_end=15971
  _DELETESERVICEACCOUNTRESPONSE._serialized_start=15973
  _DELETESERVICEACCOUNTRESPONSE._serialized_end=16003
  _LISTWORKSPACESREQUEST._serialized_start=16005
  _LISTWORKSPACESREQUEST._serialized_end=16028
  _LISTWORKSPACESRESPONSE._serialized_start=16030
  _LISTWORKSPACESRESPONSE._serialized_end=16116
  _GETWORKSPACEREQUEST._serialized_start=16118
  _GETWORKSPACEREQUEST._serialized_end=16178
  _GETWORKSPACERESPONSE._serialized_start=16180
  _GETWORKSPACERESPONSE._serialized_end=16262
  _CREATESAVEDFEATUREDATAFRAMEREQUEST._serialized_start=16265
  _CREATESAVEDFEATUREDATAFRAMEREQUEST._serialized_end=16668
  _CREATESAVEDFEATUREDATAFRAMERESPONSE._serialized_start=16671
  _CREATESAVEDFEATUREDATAFRAMERESPONSE._serialized_end=16806
  _ARCHIVESAVEDFEATUREDATAFRAMEREQUEST._serialized_start=16808
  _ARCHIVESAVEDFEATUREDATAFRAMEREQUEST._serialized_end=16931
  _ARCHIVESAVEDFEATUREDATAFRAMERESPONSE._serialized_start=16933
  _ARCHIVESAVEDFEATUREDATAFRAMERESPONSE._serialized_end=16971
  _GETSAVEDFEATUREDATAFRAMEREQUEST._serialized_start=16974
  _GETSAVEDFEATUREDATAFRAMEREQUEST._serialized_end=17205
  _GETCLUSTERADMININFORESPONSE._serialized_start=17208
  _GETCLUSTERADMININFORESPONSE._serialized_end=17373
  _CREATECLUSTERUSERREQUEST._serialized_start=17375
  _CREATECLUSTERUSERREQUEST._serialized_end=17434
  _CREATECLUSTERUSERRESPONSE._serialized_start=17436
  _CREATECLUSTERUSERRESPONSE._serialized_end=17500
  _DELETECLUSTERUSERREQUEST._serialized_start=17502
  _DELETECLUSTERUSERREQUEST._serialized_end=17553
  _DELETECLUSTERUSERRESPONSE._serialized_start=17555
  _DELETECLUSTERUSERRESPONSE._serialized_end=17619
  _CLUSTERUSERACTIONREQUEST._serialized_start=17622
  _CLUSTERUSERACTIONREQUEST._serialized_end=17848
  _CLUSTERUSERACTIONRESPONSE._serialized_start=17850
  _CLUSTERUSERACTIONRESPONSE._serialized_end=17914
  _GETSAVEDFEATUREDATAFRAMERESPONSE._serialized_start=17917
  _GETSAVEDFEATUREDATAFRAMERESPONSE._serialized_end=18049
  _GETALLSAVEDFEATUREDATAFRAMESREQUEST._serialized_start=18051
  _GETALLSAVEDFEATUREDATAFRAMESREQUEST._serialized_end=18118
  _GETALLSAVEDFEATUREDATAFRAMESRESPONSE._serialized_start=18121
  _GETALLSAVEDFEATUREDATAFRAMESRESPONSE._serialized_end=18259
  _INGESTDATAFRAMEREQUEST._serialized_start=18262
  _INGESTDATAFRAMEREQUEST._serialized_end=18418
  _INGESTDATAFRAMERESPONSE._serialized_start=18420
  _INGESTDATAFRAMERESPONSE._serialized_end=18445
  _GETNEWINGESTDATAFRAMEINFOREQUEST._serialized_start=18447
  _GETNEWINGESTDATAFRAMEINFOREQUEST._serialized_end=18558
  _GETNEWINGESTDATAFRAMEINFORESPONSE._serialized_start=18560
  _GETNEWINGESTDATAFRAMEINFORESPONSE._serialized_end=18676
  _GETUSERDEPLOYMENTSETTINGSRESPONSE._serialized_start=18679
  _GETUSERDEPLOYMENTSETTINGSRESPONSE._serialized_end=18815
  _UPDATEUSERDEPLOYMENTSETTINGSREQUEST._serialized_start=18818
  _UPDATEUSERDEPLOYMENTSETTINGSREQUEST._serialized_end=19015
  _UPDATEUSERDEPLOYMENTSETTINGSRESPONSE._serialized_start=19017
  _UPDATEUSERDEPLOYMENTSETTINGSRESPONSE._serialized_end=19118
  _GETINTERNALSPARKCLUSTERSTATUSRESPONSE._serialized_start=19120
  _GETINTERNALSPARKCLUSTERSTATUSRESPONSE._serialized_end=19230
  _GETDELETEENTITIESINFOREQUEST._serialized_start=19232
  _GETDELETEENTITIESINFOREQUEST._serialized_end=19339
  _GETDELETEENTITIESINFORESPONSE._serialized_start=19342
  _GETDELETEENTITIESINFORESPONSE._serialized_end=19544
  _DELETEENTITIESREQUEST._serialized_start=19547
  _DELETEENTITIESREQUEST._serialized_end=19790
  _DELETEENTITIESRESPONSE._serialized_start=19792
  _DELETEENTITIESRESPONSE._serialized_end=19816
  _GETHIVEMETADATAREQUEST._serialized_start=19819
  _GETHIVEMETADATAREQUEST._serialized_end=20068
  _GETHIVEMETADATAREQUEST_ACTION._serialized_start=19980
  _GETHIVEMETADATAREQUEST_ACTION._serialized_end=20068
  _GETHIVEMETADATARESPONSE._serialized_start=20071
  _GETHIVEMETADATARESPONSE._serialized_end=20408
  _GETFILEMETADATAREQUEST._serialized_start=20410
  _GETFILEMETADATAREQUEST._serialized_end=20485
  _GETFILEMETADATARESPONSE._serialized_start=20488
  _GETFILEMETADATARESPONSE._serialized_end=20659
  _VALIDATEFCOSREQUEST._serialized_start=20661
  _VALIDATEFCOSREQUEST._serialized_end=20743
  _VALIDATEFCOSRESPONSE._serialized_start=20746
  _VALIDATEFCOSRESPONSE._serialized_end=20976
  _VALIDATELOCALFCOREQUEST._serialized_start=20979
  _VALIDATELOCALFCOREQUEST._serialized_end=21128
  _VALIDATELOCALFCORESPONSE._serialized_start=21131
  _VALIDATELOCALFCORESPONSE._serialized_end=21287
  _GETONBOARDINGSTATUSREQUEST._serialized_start=21289
  _GETONBOARDINGSTATUSREQUEST._serialized_end=21347
  _GETONBOARDINGSTATUSRESPONSE._serialized_start=21350
  _GETONBOARDINGSTATUSRESPONSE._serialized_end=21634
  _SETONBOARDINGSTATUSREQUEST._serialized_start=21636
  _SETONBOARDINGSTATUSREQUEST._serialized_end=21729
  _GETDATAPLATFORMSETUPSTATUSRESPONSE._serialized_start=21732
  _GETDATAPLATFORMSETUPSTATUSRESPONSE._serialized_end=21878
  _GETRETRIEVEFEATURESNOTEBOOKRESPONSE._serialized_start=21880
  _GETRETRIEVEFEATURESNOTEBOOKRESPONSE._serialized_end=21935
  _GETOBSERVABILITYCONFIGREQUEST._serialized_start=21937
  _GETOBSERVABILITYCONFIGREQUEST._serialized_end=22042
  _GETOBSERVABILITYCONFIGRESPONSE._serialized_start=22045
  _GETOBSERVABILITYCONFIGRESPONSE._serialized_end=22210
  _QUERYMETRICREQUEST._serialized_start=22213
  _QUERYMETRICREQUEST._serialized_end=22488
  _QUERYMETRICRESPONSE._serialized_start=22491
  _QUERYMETRICRESPONSE._serialized_end=22992
  _GETFEATUREVALIDATIONHISTORYREQUEST._serialized_start=22995
  _GETFEATUREVALIDATIONHISTORYREQUEST._serialized_end=23132
  _GETFEATUREVALIDATIONHISTORYRESPONSE._serialized_start=23135
  _GETFEATUREVALIDATIONHISTORYRESPONSE._serialized_end=23313
  _GETFEATUREVALIDATIONRESULTREQUEST._serialized_start=23316
  _GETFEATUREVALIDATIONRESULTREQUEST._serialized_end=23828
  _GETFEATUREVALIDATIONRESULTRESPONSE._serialized_start=23831
  _GETFEATUREVALIDATIONRESULTRESPONSE._serialized_end=23971
  _GETFEATUREVALIDATIONSUMMARYREQUEST._serialized_start=23974
  _GETFEATUREVALIDATIONSUMMARYREQUEST._serialized_end=24196
  _GETFEATUREVALIDATIONSUMMARYRESPONSE._serialized_start=24199
  _GETFEATUREVALIDATIONSUMMARYRESPONSE._serialized_end=24513
  _GETUSERREQUEST._serialized_start=24515
  _GETUSERREQUEST._serialized_end=24569
  _GETUSERRESPONSE._serialized_start=24571
  _GETUSERRESPONSE._serialized_end=24638
  _GETFEATURESERVERCONFIGREQUEST._serialized_start=24640
  _GETFEATURESERVERCONFIGREQUEST._serialized_end=24671
  _GETFEATURESERVERCONFIGRESPONSE._serialized_start=24674
  _GETFEATURESERVERCONFIGRESPONSE._serialized_end=24818
  _SETFEATURESERVERCONFIGREQUEST._serialized_start=24820
  _SETFEATURESERVERCONFIGREQUEST._serialized_end=24873
  _METADATASERVICE._serialized_start=24941
  _METADATASERVICE._serialized_end=44313
# @@protoc_insertion_point(module_scope)
